@@ -1,6 +1,6 @@
 //
 //  CocoaVLayout.h
-//  
+//
 //
 //  Created by Samuel Strupp on 10.08.10.
 //
@@ -8,15 +8,16 @@
 #import <Cocoa/Cocoa.h>
 #import "CocoaGwenGUIProtocol.h"
 
-@interface CocoaVLayout : NSView <CocoaGwenGUIProtocol> {
-	NSMutableArray *subviewsInOrder;
-	BOOL fillX;
-	BOOL fillY;
+@interface CocoaVLayout : NSView <CocoaGwenGUIProtocol>
+{
+  NSMutableArray *subviewsInOrder;
+  BOOL fillX;
+  BOOL fillY;
 }
 
 @property BOOL fillX;
 @property BOOL fillY;
 
--(void) addLayoutSubview:(NSView*)new_subview ;
+-(void) addLayoutSubview:(NSView *)new_subview ;
 
 @end
