@@ -13,20 +13,21 @@
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WDialog_SetIntProperty(GWEN_WIDGET *w,
-				   GWEN_DIALOG_PROPERTY prop,
-				   int index,
-				   int value,
-				   int doSignal) {
+                                   GWEN_DIALOG_PROPERTY prop,
+                                   GWEN_UNUSED int index,
+                                   int value,
+                                   GWEN_UNUSED int doSignal)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
-  
+
   case GWEN_DialogProperty_Focus:
     gtk_widget_grab_focus(GTK_WIDGET(g));
     return 0;
@@ -52,8 +53,8 @@ int Gtk2Gui_WDialog_SetIntProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return GWEN_ERROR_INVALID;
 }
 
@@ -62,15 +63,16 @@ int Gtk2Gui_WDialog_SetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WDialog_GetIntProperty(GWEN_WIDGET *w,
-				 GWEN_DIALOG_PROPERTY prop,
-				 int index,
-				 int defaultValue) {
+                                   GWEN_DIALOG_PROPERTY prop,
+                                   GWEN_UNUSED int index,
+                                   int defaultValue)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -97,8 +99,8 @@ int Gtk2Gui_WDialog_GetIntProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return defaultValue;
 }
 
@@ -106,16 +108,17 @@ int Gtk2Gui_WDialog_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WDialog_SetCharProperty(GWEN_WIDGET *w,
-				  GWEN_DIALOG_PROPERTY prop,
-				  int index,
-				  const char *value,
-				  int doSignal) {
+                                    GWEN_DIALOG_PROPERTY prop,
+                                    GWEN_UNUSED int index,
+                                    const char *value,
+                                    GWEN_UNUSED int doSignal)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     gtk_window_set_title(GTK_WINDOW(g), value);
     return 0;
@@ -124,24 +127,25 @@ int Gtk2Gui_WDialog_SetCharProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return GWEN_ERROR_INVALID;
 }
 
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
-					  GWEN_DIALOG_PROPERTY prop,
-					  int index,
-					  const char *defaultValue) {
+const char *Gtk2Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
+                                            GWEN_DIALOG_PROPERTY prop,
+                                            GWEN_UNUSED int index,
+                                            const char *defaultValue)
+{
   GtkWindow *g;
 
   g=GTK_WINDOW(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Title:
     return gtk_window_get_title(GTK_WINDOW(g));
   default:
@@ -149,15 +153,16 @@ const char* Gtk2Gui_WDialog_GetCharProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return defaultValue;
 }
 
 
 
 static GWENHYWFAR_CB
-int Gtk2Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
+int Gtk2Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild)
+{
   GtkWidget *g;
   GtkWidget *gChild;
 
@@ -174,12 +179,13 @@ int Gtk2Gui_WDialog_AddChildGuiWidget(GWEN_WIDGET *w, GWEN_WIDGET *wChild) {
 
 
 
-int Gtk2Gui_WDialog_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WDialog_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
+  /*uint32_t flags;*/
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   s=GWEN_Widget_GetText(w, 0);
 
   g=gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -187,8 +193,8 @@ int Gtk2Gui_WDialog_Setup(GWEN_WIDGET *w) {
   if (s && *s)
     gtk_window_set_title(GTK_WINDOW(g), s);
 
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WDialog_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WDialog_GetIntProperty);
