@@ -13,10 +13,11 @@
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
-					GWEN_DIALOG_PROPERTY prop,
-					int index,
-					int value,
-					int doSignal) {
+                                        GWEN_DIALOG_PROPERTY prop,
+                                        GWEN_UNUSED int index,
+                                        int value,
+                                        GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -25,11 +26,11 @@ int Gtk2Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
   gs=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(gs);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(gs), (value==0)?FALSE:TRUE);
     return 0;
-  
+
   case GWEN_DialogProperty_Focus:
     gtk_widget_grab_focus(GTK_WIDGET(gs));
     return 0;
@@ -44,8 +45,8 @@ int Gtk2Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return GWEN_ERROR_INVALID;
 }
 
@@ -54,9 +55,10 @@ int Gtk2Gui_WTextBrowser_SetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
-					GWEN_DIALOG_PROPERTY prop,
-					int index,
-					int defaultValue) {
+                                        GWEN_DIALOG_PROPERTY prop,
+                                        GWEN_UNUSED int index,
+                                        int defaultValue)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -68,7 +70,7 @@ int Gtk2Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_CONTENT));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(gs))==TRUE)?1:0;
 
@@ -86,8 +88,8 @@ int Gtk2Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return defaultValue;
 }
 
@@ -95,10 +97,11 @@ int Gtk2Gui_WTextBrowser_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
-					 GWEN_DIALOG_PROPERTY prop,
-					 int index,
-					 const char *value,
-					 int doSignal) {
+                                         GWEN_DIALOG_PROPERTY prop,
+                                         GWEN_UNUSED int index,
+                                         const char *value,
+                                         GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
   GWEN_BUFFER *tbuf;
@@ -112,7 +115,7 @@ int Gtk2Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
   if (value && *value)
     Gtk2Gui_GetRawText(value, tbuf);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkAdjustment *va;
@@ -134,8 +137,8 @@ int Gtk2Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   GWEN_Buffer_free(tbuf);
   return GWEN_ERROR_INVALID;
 }
@@ -143,10 +146,11 @@ int Gtk2Gui_WTextBrowser_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
-						 GWEN_DIALOG_PROPERTY prop,
-						 int index,
-						 const char *defaultValue) {
+const char *Gtk2Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
+                                                 GWEN_DIALOG_PROPERTY prop,
+                                                 GWEN_UNUSED int index,
+                                                 const char *defaultValue)
+{
   GtkWidget *g;  /* text view */
   GtkWidget *gs; /* scrollable window */
 
@@ -155,7 +159,7 @@ const char* Gtk2Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
   gs=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(gs);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Value: {
     GtkTextBuffer *tb;
     GtkTextIter startIter;
@@ -182,21 +186,22 @@ const char* Gtk2Gui_WTextBrowser_GetCharProperty(GWEN_WIDGET *w,
   }
 
   DBG_WARN(GWEN_LOGDOMAIN,
-	   "Function is not appropriate for this type of widget (%s)",
-	   GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
+           "Function is not appropriate for this type of widget (%s)",
+           GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
   return defaultValue;
 }
 
 
 
-int Gtk2Gui_WTextBrowser_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WTextBrowser_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *gs;
   GtkWidget *g;
   const char *s;
-  uint32_t flags;
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
   s=GWEN_Widget_GetText(w, 0);
 
@@ -214,8 +219,8 @@ int Gtk2Gui_WTextBrowser_Setup(GWEN_WIDGET *w) {
     GWEN_Buffer_free(tbuf);
   }
 
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) gs);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) gs);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WTextBrowser_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WTextBrowser_GetIntProperty);
