@@ -1,6 +1,6 @@
 /***************************************************************************
  begin       : Thu Oct 30 2003
- copyright   : (C) 2003-2013 by Martin Preuss
+ copyright   : (C) 2021 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -30,7 +30,6 @@
 /* disable DBG_DEBUG() and DBG_VERBOUS() */
 #define DISABLE_DEBUGLOG
 
-#include "csv_p.h"
 #include <gwenhywfar/text.h>
 #include <gwenhywfar/debug.h>
 #include <gwenhywfar/stringlist.h>
@@ -48,58 +47,60 @@
 
 
 
-int GWEN_CSV_GetNameAndIndex(const char *name,
-                             char *buffer,
-                             unsigned int size)
+GWENHYWFAR_EXPORT GWEN_PLUGIN *dbio_csv_factory(GWEN_PLUGIN_MANAGER *pm, const char *modName, const char *fileName);
+
+static GWEN_DBIO *_csvFactory(GWEN_PLUGIN *pl);
+static int _csvExport(GWEN_DBIO *dbio,
+				GWEN_SYNCIO *sio,
+				GWEN_DB_NODE *data,
+				GWEN_DB_NODE *cfg,
+				uint32_t flags);
+
+static int _csvImport(GWEN_DBIO *dbio,
+		      GWEN_SYNCIO *sio,
+		      GWEN_DB_NODE *data,
+		      GWEN_DB_NODE *cfg,
+		      uint32_t flags);
+
+static GWEN_DBIO_CHECKFILE_RESULT _csvCheckFile(GWEN_DBIO *dbio, const char *fname);
+
+
+static void _stringListToDb(GWEN_STRINGLIST *sl, GWEN_DB_NODE *colgr, GWEN_DB_NODE *dbData);
+static GWEN_STRINGLIST *_splitFixedWithStringIntoStringlist(const char *s, int condense, GWEN_DB_NODE *cfg);
+static int _getNameAndIndex(const char *name, char *buffer, unsigned int size);
+static int _readCsvLine(GWEN_FAST_BUFFER *fb, GWEN_STRINGLIST *sl);
+
+
+
+
+GWEN_DBIO *_csvFactory(GWEN_UNUSED GWEN_PLUGIN *pl)
 {
-  unsigned int i;
-  int rv;
+  GWEN_DBIO *dbio;
 
-  i=0;
-  rv=0;
-  /* read and copy name */
-  while (name[i] && name[i]!='[' && i<size) {
-    buffer[i]=name[i];
-    i++;
-  } /* while */
+  dbio=GWEN_DBIO_new("csv", "Imports and exports CSV data");
+  GWEN_DBIO_SetImportFn(dbio, _csvImport);
+  GWEN_DBIO_SetExportFn(dbio, _csvExport);
+  GWEN_DBIO_SetCheckFileFn(dbio, _csvCheckFile);
+  return dbio;
+}
 
-  if (i>=size) {
-    DBG_INFO(0, "Name too long (%d>=%d)", i, size);
-    return -1;
-  }
-  buffer[i]=0;
 
-  /* read and copy index, if any */
-  if (name[i]=='[') {
-    char numbuffer[16];
-    unsigned int j;
+GWEN_PLUGIN *dbio_csv_factory(GWEN_PLUGIN_MANAGER *pm, const char *modName, const char *fileName)
+{
+  GWEN_PLUGIN *pl;
 
-    j=0;
-    i++;
-    while (name[i] && name[i]!=']' && j<sizeof(numbuffer)) {
-      numbuffer[j]=name[i];
-      i++;
-      j++;
-    } /* while */
-    if (j>=sizeof(numbuffer)) {
-      DBG_INFO(0, "Index number too long (%u>=%d)", j,
-               (int)(sizeof(numbuffer)));
-      return -1;
-    }
-    numbuffer[j]=0;
-    rv=atoi(numbuffer);
-  }
+  pl=GWEN_DBIO_Plugin_new(pm, modName, fileName);
+  assert(pl);
+
+  GWEN_DBIO_Plugin_SetFactoryFn(pl, _csvFactory);
+
+  return pl;
 
-  return rv;
 }
 
 
 
-int GWEN_DBIO_CSV_Export(GWEN_DBIO *dbio,
-                         GWEN_SYNCIO *sio,
-                         GWEN_DB_NODE *data,
-                         GWEN_DB_NODE *cfg,
-                         GWEN_UNUSED uint32_t flags)
+int _csvExport(GWEN_DBIO *dbio, GWEN_SYNCIO *sio, GWEN_DB_NODE *data, GWEN_DB_NODE *cfg, GWEN_UNUSED uint32_t flags)
 {
   GWEN_DB_NODE *colgr;
   GWEN_DB_NODE *n;
@@ -160,7 +161,7 @@ int GWEN_DBIO_CSV_Export(GWEN_DBIO *dbio,
         break;
       }
       /* break down to name and index */
-      idx=GWEN_CSV_GetNameAndIndex(p, namebuffer, sizeof(namebuffer));
+      idx=_getNameAndIndex(p, namebuffer, sizeof(namebuffer));
       if (idx==-1) {
         DBG_INFO(0, "Error in configuration: Bad name for column %d",
                  column);
@@ -250,7 +251,7 @@ int GWEN_DBIO_CSV_Export(GWEN_DBIO *dbio,
         }
 
         /* break down to name and index */
-        idx=GWEN_CSV_GetNameAndIndex(p, namebuffer, sizeof(namebuffer));
+        idx=_getNameAndIndex(p, namebuffer, sizeof(namebuffer));
         if (idx==-1) {
           DBG_INFO(GWEN_LOGDOMAIN, "Error in configuration: Bad name for column %d",
                    column);
@@ -332,11 +333,7 @@ int GWEN_DBIO_CSV_Export(GWEN_DBIO *dbio,
 
 
 
-int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
-                         GWEN_SYNCIO *sio,
-                         GWEN_DB_NODE *data,
-                         GWEN_DB_NODE *cfg,
-                         GWEN_UNUSED uint32_t flags)
+int _csvImport(GWEN_DBIO *dbio, GWEN_SYNCIO *sio, GWEN_DB_NODE *data, GWEN_DB_NODE *cfg, GWEN_UNUSED uint32_t flags)
 {
   GWEN_DB_NODE *colgr;
   int delimiter;
@@ -345,7 +342,6 @@ int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
   const char *groupName;
   int err;
   int title;
-  GWEN_STRINGLIST *sl;
   GWEN_BUFFER *lbuffer;
   char delimiters[2];
   int lines;
@@ -386,17 +382,11 @@ int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
   if (title)
     ignoreLines++;
 
-  sl=GWEN_StringList_new();
   lbuffer=GWEN_Buffer_new(0, 256, 0, 1);
 
   lines=0;
   for (;;) {
-    GWEN_BUFFER *wbuffer;
-    int rv;
     const char *s;
-    GWEN_STRINGLISTENTRY *se;
-    int col;
-    GWEN_DB_NODE *n;
 
     /* read line */
     DBG_DEBUG(GWEN_LOGDOMAIN, "Reading line %d", lines);
@@ -410,7 +400,6 @@ int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
       else {
         DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
         GWEN_Buffer_free(lbuffer);
-        GWEN_StringList_free(sl);
         GWEN_FastBuffer_free(fb);
         return err;
       }
@@ -420,120 +409,34 @@ int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
       DBG_VERBOUS(GWEN_LOGDOMAIN, "Ignoring line %d", lines);
     }
     else {
-      /* read columns */
-      wbuffer=GWEN_Buffer_new(0, 256, 0, 1);
+      GWEN_STRINGLIST *sl;
 
       s=GWEN_Buffer_GetStart(lbuffer);
-      if (fixedWidth) {
-        int i;
-        unsigned int llength;
-        unsigned int lpos=0;
+      if (fixedWidth)
+	sl=_splitFixedWithStringIntoStringlist(s, condense, cfg);
+      else
+	sl=GWEN_StringList_fromString2(s, delimiters, 0,
+				       GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS |
+				       GWEN_TEXT_FLAGS_DEL_TRAILING_BLANKS |
+				       GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
+				       GWEN_TEXT_FLAGS_DEL_QUOTES);
+      if (sl) {
+	GWEN_DB_NODE *n;
 
-        llength=strlen(s);
-        for (i=0; ; i++) {
-          int w;
-          char *t=0;
-          int left;
-
-          left=llength-lpos;
-          w=GWEN_DB_GetIntValue(cfg, "width", i, -1);
-          if (w<1)
-            break;
-          if (w>left)
-            w=left;
-          if (w<1)
-            break;
-          t=(char *)malloc(w+1);
-          memmove(t, s, w);
-          t[w]=0;
-          if (condense) {
-            int j;
-
-            for (j=w-1; j>=0; j--) {
-              if ((unsigned char)(t[j])>32) {
-                break;
-              }
-              t[j]=0;
-            }
-          }
-          /* take over new string */
-          GWEN_StringList_AppendString(sl, t, 1, 0);
-          s+=w;
-          lpos+=w;
-        }
+	/* store columns to db */
+	n=GWEN_DB_Group_new(groupName);
+	_stringListToDb(sl, colgr, n);
+	GWEN_DB_AddGroup(data, n); /* add data */
+	GWEN_StringList_free(sl);
       }
       else {
-        while (*s) {
-          rv=GWEN_Text_GetWordToBuffer(s, delimiters, wbuffer,
-                                       GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS |
-                                       GWEN_TEXT_FLAGS_DEL_TRAILING_BLANKS |
-                                       GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
-                                       GWEN_TEXT_FLAGS_DEL_QUOTES,
-                                       &s);
-          if (rv) {
-            DBG_DEBUG(GWEN_LOGDOMAIN, "here (%d)", rv);
-            GWEN_Buffer_free(wbuffer);
-            GWEN_Buffer_free(lbuffer);
-            GWEN_StringList_free(sl);
-            GWEN_FastBuffer_free(fb);
-            return rv;
-          }
-          GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(wbuffer), 0, 0);
-          GWEN_Buffer_Reset(wbuffer);
-          if (*s) {
-            if (strchr(delimiters, *s))
-              s++;
-          }
-        } /* while */
+        DBG_INFO(GWEN_LOGDOMAIN, "Line contains no strings");
       }
-      GWEN_Buffer_free(wbuffer);
-
-      /* store columns to db */
-      n=GWEN_DB_Group_new(groupName);
-      se=GWEN_StringList_FirstEntry(sl);
-      col=1;
-      while (se) {
-        char nbuff[16];
-        const char *vcol;
-
-        DBG_DEBUG(0, "Handling column %d", col);
-        nbuff[0]=0;
-        snprintf(nbuff, sizeof(nbuff)-1, "%i", col);
-        nbuff[sizeof(nbuff)-1]=0;
-
-        vcol=GWEN_DB_GetCharValue(colgr, nbuff, 0, 0);
-        if (vcol) {
-          const char *bracket;
-          GWEN_BUFFER *vname;
-
-          bracket=strchr(vcol, '[');
-          if (bracket) {
-            /* copy column name without index */
-            vname=GWEN_Buffer_new(0, bracket-vcol+1, 0, 1);
-            GWEN_Buffer_AppendBytes(vname, vcol, bracket-vcol);
-            vcol=GWEN_Buffer_GetStart(vname);
-          }
-          else
-            vname=0;
-          GWEN_DB_SetCharValue(n, GWEN_DB_FLAGS_DEFAULT,
-                               vcol, GWEN_StringListEntry_Data(se));
-          GWEN_Buffer_free(vname);
-        }
-
-        se=GWEN_StringListEntry_Next(se);
-        col++;
-      } /* while */
-
-      /* add db to data */
-      GWEN_DB_AddGroup(data, n);
     } /* if this is not the title line */
-    GWEN_StringList_Clear(sl);
     lines++;
-  } /* while */
+  } /* for */
 
   GWEN_Buffer_free(lbuffer);
-  GWEN_StringList_free(sl);
-
   GWEN_FastBuffer_free(fb);
 
   return 0;
@@ -541,59 +444,7 @@ int GWEN_DBIO_CSV_Import(GWEN_DBIO *dbio,
 
 
 
-int GWEN_DBIO_CSV__ReadLine(GWEN_FAST_BUFFER *fb, GWEN_STRINGLIST *sl)
-{
-  int err;
-  const char *delimiters=";\t,";
-  GWEN_BUFFER *lbuffer;
-  GWEN_BUFFER *wbuffer;
-  int rv;
-  const char *s;
-
-  assert(fb);
-
-  /* read line */
-  lbuffer=GWEN_Buffer_new(0, 256, 0, 1);
-  GWEN_Buffer_Reset(lbuffer);
-  err=GWEN_FastBuffer_ReadLineToBuffer(fb, lbuffer);
-  if (err<0) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
-    GWEN_Buffer_free(lbuffer);
-    return err;
-  }
-
-  /* read columns */
-  wbuffer=GWEN_Buffer_new(0, 256, 0, 1);
-
-  s=GWEN_Buffer_GetStart(lbuffer);
-  while (*s) {
-    rv=GWEN_Text_GetWordToBuffer(s, delimiters, wbuffer,
-                                 GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS |
-                                 GWEN_TEXT_FLAGS_DEL_TRAILING_BLANKS |
-                                 GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
-                                 GWEN_TEXT_FLAGS_DEL_QUOTES,
-                                 &s);
-    if (rv) {
-      GWEN_Buffer_free(wbuffer);
-      GWEN_Buffer_free(lbuffer);
-      return rv;
-    }
-    GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(wbuffer), 0, 0);
-    GWEN_Buffer_Reset(wbuffer);
-    if (*s) {
-      if (strchr(delimiters, *s))
-        s++;
-    }
-  } /* while */
-  GWEN_Buffer_free(wbuffer);
-  GWEN_Buffer_free(lbuffer);
-
-  return 0;
-}
-
-
-
-GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_CSV_CheckFile(GWEN_UNUSED GWEN_DBIO *dbio, const char *fname)
+GWEN_DBIO_CHECKFILE_RESULT _csvCheckFile(GWEN_UNUSED GWEN_DBIO *dbio, const char *fname)
 {
   int i;
   int rv;
@@ -614,7 +465,7 @@ GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_CSV_CheckFile(GWEN_UNUSED GWEN_DBIO *dbio,
 
   /* read line into string list */
   sl=GWEN_StringList_new();
-  if (GWEN_DBIO_CSV__ReadLine(fb, sl)) {
+  if (_readCsvLine(fb, sl)) {
     DBG_INFO(GWEN_LOGDOMAIN, "Error reading a line");
     GWEN_FastBuffer_free(fb);
     GWEN_SyncIo_Disconnect(sio);
@@ -646,38 +497,219 @@ GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_CSV_CheckFile(GWEN_UNUSED GWEN_DBIO *dbio,
 
 
 
-GWEN_DBIO *GWEN_DBIO_CSV_Factory(GWEN_UNUSED GWEN_PLUGIN *pl)
+GWEN_STRINGLIST *_splitFixedWithStringIntoStringlist(const char *s, int condense, GWEN_DB_NODE *cfg)
 {
-  GWEN_DBIO *dbio;
+  GWEN_STRINGLIST *sl;
+  int i;
+  unsigned int llength;
+  unsigned int lpos=0;
 
-  dbio=GWEN_DBIO_new("csv", "Imports and exports CSV data");
-  GWEN_DBIO_SetImportFn(dbio, GWEN_DBIO_CSV_Import);
-  GWEN_DBIO_SetExportFn(dbio, GWEN_DBIO_CSV_Export);
-  GWEN_DBIO_SetCheckFileFn(dbio, GWEN_DBIO_CSV_CheckFile);
-  return dbio;
+  sl=GWEN_StringList_new();
+
+  llength=strlen(s);
+  for (i=0; ; i++) {
+    int w;
+    char *t=0;
+    int left;
+  
+    left=llength-lpos;
+    w=GWEN_DB_GetIntValue(cfg, "width", i, -1);
+    if (w<1)
+      break;
+    if (w>left)
+      w=left;
+    if (w<1)
+      break;
+    t=(char *)malloc(w+1);
+    memmove(t, s, w);
+    t[w]=0;
+    if (condense) {
+      int j;
+  
+      for (j=w-1; j>=0; j--) {
+	if ((unsigned char)(t[j])>32) {
+	  break;
+	}
+	t[j]=0;
+      }
+    }
+    /* take over new string */
+    GWEN_StringList_AppendString(sl, t, 1, 0);
+    s+=w;
+    lpos+=w;
+  }
+
+  if (GWEN_StringList_Count(sl)==0) {
+    GWEN_StringList_free(sl);
+    return NULL;
+  }
+
+  return sl;
 }
 
 
 
-GWEN_PLUGIN *dbio_csv_factory(GWEN_PLUGIN_MANAGER *pm,
-                              const char *modName,
-                              const char *fileName)
+void _stringListToDb(GWEN_STRINGLIST *sl, GWEN_DB_NODE *colgr, GWEN_DB_NODE *dbData)
 {
-  GWEN_PLUGIN *pl;
+  GWEN_STRINGLISTENTRY *se;
+  int col;
 
-  pl=GWEN_DBIO_Plugin_new(pm, modName, fileName);
-  assert(pl);
+  /* store columns to db */
+  se=GWEN_StringList_FirstEntry(sl);
+  col=1;
+  while (se) {
+    char nbuff[16];
+    const char *vcol;
+    const char *sColumn;
 
-  GWEN_DBIO_Plugin_SetFactoryFn(pl, GWEN_DBIO_CSV_Factory);
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Handling column %d", col);
+    nbuff[0]=0;
+    snprintf(nbuff, sizeof(nbuff)-1, "%i", col);
+    nbuff[sizeof(nbuff)-1]=0;
+    sColumn=GWEN_StringListEntry_Data(se);
 
-  return pl;
+    vcol=GWEN_DB_GetCharValue(colgr, nbuff, 0, 0);
+    if (vcol) {
+      const char *bracket;
+      GWEN_BUFFER *vname;
 
+      bracket=strchr(vcol, '[');
+      if (bracket) {
+        /* copy column name without index */
+        vname=GWEN_Buffer_new(0, bracket-vcol+1, 0, 1);
+        GWEN_Buffer_AppendBytes(vname, vcol, bracket-vcol);
+        vcol=GWEN_Buffer_GetStart(vname);
+      }
+      else
+        vname=0;
+      GWEN_DB_SetCharValue(dbData, GWEN_DB_FLAGS_DEFAULT, vcol, sColumn);
+      GWEN_Buffer_free(vname);
+    }
+    else {
+      GWEN_DB_NODE *dbSubFields;
+
+      dbSubFields=GWEN_DB_GetGroup(colgr, GWEN_PATH_FLAGS_NAMEMUSTEXIST, nbuff);
+      if (dbSubFields) {
+	GWEN_STRINGLIST *slSubFields;
+	const char *delimiter;
+
+	delimiter=GWEN_DB_GetCharValue(dbSubFields, "delimiter", 0, "/");
+        slSubFields=GWEN_StringList_fromString2(sColumn,
+						delimiter, 0,
+						GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS |
+						GWEN_TEXT_FLAGS_DEL_TRAILING_BLANKS |
+						GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
+						GWEN_TEXT_FLAGS_DEL_QUOTES);
+        if (slSubFields) {
+	  _stringListToDb(slSubFields, dbSubFields, dbData); /* recursion */
+	  GWEN_StringList_free(slSubFields);
+	}
+      }
+    }
+
+    se=GWEN_StringListEntry_Next(se);
+    col++;
+  } /* while */
 }
 
 
 
+/* only used by _csvCheckFile(), not for actual import! */
+int _readCsvLine(GWEN_FAST_BUFFER *fb, GWEN_STRINGLIST *sl)
+{
+  int err;
+  const char *delimiters=";\t,";
+  GWEN_BUFFER *lbuffer;
+  GWEN_BUFFER *wbuffer;
+  int rv;
+  const char *s;
+
+  assert(fb);
+
+  /* read line */
+  lbuffer=GWEN_Buffer_new(0, 256, 0, 1);
+  GWEN_Buffer_Reset(lbuffer);
+  err=GWEN_FastBuffer_ReadLineToBuffer(fb, lbuffer);
+  if (err<0) {
+    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    GWEN_Buffer_free(lbuffer);
+    return err;
+  }
+
+  /* read columns */
+  wbuffer=GWEN_Buffer_new(0, 256, 0, 1);
+
+  s=GWEN_Buffer_GetStart(lbuffer);
+  while (*s) {
+    rv=GWEN_Text_GetWordToBuffer(s, delimiters, wbuffer,
+                                 GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS |
+                                 GWEN_TEXT_FLAGS_DEL_TRAILING_BLANKS |
+                                 GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
+                                 GWEN_TEXT_FLAGS_DEL_QUOTES,
+                                 &s);
+    if (rv<0) {
+      DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Buffer_free(wbuffer);
+      GWEN_Buffer_free(lbuffer);
+      return rv;
+    }
+
+    GWEN_StringList_AppendString(sl, GWEN_Buffer_GetStart(wbuffer), 0, 0);
+    GWEN_Buffer_Reset(wbuffer);
+    if (*s) {
+      if (strchr(delimiters, *s))
+        s++;
+    }
+  } /* while */
+  GWEN_Buffer_free(wbuffer);
+  GWEN_Buffer_free(lbuffer);
+
+  return 0;
+}
 
 
 
+int _getNameAndIndex(const char *name, char *buffer, unsigned int size)
+{
+  unsigned int i;
+  int rv;
+
+  i=0;
+  rv=0;
+  /* read and copy name */
+  while (name[i] && name[i]!='[' && i<size) {
+    buffer[i]=name[i];
+    i++;
+  } /* while */
+
+  if (i>=size) {
+    DBG_INFO(0, "Name too long (%d>=%d)", i, size);
+    return -1;
+  }
+  buffer[i]=0;
+
+  /* read and copy index, if any */
+  if (name[i]=='[') {
+    char numbuffer[16];
+    unsigned int j;
+
+    j=0;
+    i++;
+    while (name[i] && name[i]!=']' && j<sizeof(numbuffer)) {
+      numbuffer[j]=name[i];
+      i++;
+      j++;
+    } /* while */
+    if (j>=sizeof(numbuffer)) {
+      DBG_INFO(0, "Index number too long (%u>=%d)", j,
+               (int)(sizeof(numbuffer)));
+      return -1;
+    }
+    numbuffer[j]=0;
+    rv=atoi(numbuffer);
+  }
+
+  return rv;
+}
 
 
