@@ -32,6 +32,8 @@
 
 #include <gwenhywfar/error.h>
 #include <gwenhywfar/stringlist.h>
+#include <gwenhywfar/buffer.h>
+
 
 typedef enum {
   /** relative to the current working directory at calling time */
@@ -64,7 +66,7 @@ extern "C" {
 /** @name Path Management
  *
  * Gwenhywfar keeps track of registered directory paths for itself
- * and for other libraries.  
+ * and for other libraries.
  *
  * The paths are registered and stored in one global object (of
  * GWEN_DB_NODE type), so write-access to this GWEN_PathManager
@@ -132,7 +134,7 @@ GWENHYWFAR_API
 int GWEN_PathManager_AddPath(const char *callingLib,
                              const char *destLib,
                              const char *pathName,
-			     const char *pathValue);
+                             const char *pathValue);
 
 /**
  * Same as @ref GWEN_PathManager_AddPath but the path to add is given
@@ -154,7 +156,7 @@ int GWEN_PathManager_AddPath(const char *callingLib,
  * GWEN_Directory_GetHomeDirectory().
  *
  * All three variantes will then add the resulting path
- * to the PathManager. 
+ * to the PathManager.
  *
  * @param callingLib The name of the library that adds this path entry.
  *
@@ -175,14 +177,14 @@ int GWEN_PathManager_AddPath(const char *callingLib,
  */
 GWENHYWFAR_API
 int GWEN_PathManager_AddRelPath(const char *callingLib,
-				const char *destLib,
-				const char *pathName,
-				const char *pathValue,
-				GWEN_PATHMANAGER_RELMODE rm);
+                                const char *destLib,
+                                const char *pathName,
+                                const char *pathValue,
+                                GWEN_PATHMANAGER_RELMODE rm);
 /**
  * Add a directory path entry to a registered path entry in the
  * global GWEN_PathManager by looking up the directory path in the
- * Windows registry. 
+ * Windows registry.
  *
  * On non-windows platforms, the function does nothing and returns
  * zero, so you can safely call this in your multi-platform code.
@@ -239,6 +241,53 @@ int GWEN_PathManager_InsertPath(const char *callingLib,
                                 const char *pathName,
                                 const char *pathValue);
 
+/**
+ * Same as @ref GWEN_PathManager_InsertPath but the path to insert is given
+ * relative to some directory. The "relmode" argument chooses the base
+ * directory to which the given sub-directory path is appended and the
+ * result is added to this PathManager:
+ *
+ * - RelModeCwd appends the path to the current working directory at
+ * the time of calling. So future changes to the CWD do not affect
+ * this setting.
+ *
+ * - RelModeExe appends the path to the prefix of the installation
+ * location of the calling executable. This function looks up the
+ * current working directory, removes the last component (i.e. the
+ * "/bin/") to get the prefix, then adds the given relative path to
+ * it.
+ *
+ * - RelModeHome appends the path to the return value of
+ * GWEN_Directory_GetHomeDirectory().
+ *
+ * All three variantes will then add the resulting path
+ * to the PathManager.
+ *
+ * @param callingLib The name of the library that adds this path entry.
+ *
+ * @param destLib The name of the library that this path is supposed to
+ * belong to.
+ *
+ * @param pathName A string identifier for this registered path.
+ *
+ * @param pathValue The actual directory path relative to the prefix
+ * of the current working directory that should be added to this
+ * registered path.
+ *
+ * @param rm The Flag to choose the starting directory to which the
+ * path is appended.
+ *
+ * @return Zero on success, or GWEN_ERROR_NOT_FOUND if the @c
+ * pathName was not found.
+ */
+GWENHYWFAR_API
+int GWEN_PathManager_InsertRelPath(const char *callingLib,
+                                   const char *destLib,
+                                   const char *pathName,
+                                   const char *pathValue,
+                                   GWEN_PATHMANAGER_RELMODE rm);
+
+
 /**
  * Removes a directory path entry from a registered path entry in
  * the global GWEN_PathManager.
@@ -309,6 +358,54 @@ GWENHYWFAR_API
 GWEN_STRINGLIST *GWEN_PathManager_GetPaths(const char *destLib,
                                            const char *pathName);
 
+
+/**
+ * This functions tries to find a given file using all
+ * path entries under the registered @c pathName.
+ *
+ * @param destLib The name of the library that this path is supposed to
+ * belong to.
+ *
+ * @param pathName A string identifier for this registered path.
+ *
+ * @param fileName Name of the file (may contain partial paths, like in
+ * "dialogs/testdialog.xml"
+ *
+ * @param fbuf buffer to receive the full path to access the file
+ *
+ * @return 0 on success (in that case @c fbuf will be filled), an
+ * error code otherwise.
+ */
+GWENHYWFAR_API
+int GWEN_PathManager_FindFile(const char *destLib,
+                              const char *pathName,
+                              const char *fileName,
+                              GWEN_BUFFER *fbuf);
+
+/**
+ * This function calls @ref GWEN_Directory_GetMatchingFilesRecursively() on every
+ * path entry under the registered @c pathName.
+ *
+ * @return 0 if ok, error code on error
+ *
+ * @param destLib The name of the library that this path is supposed to
+ * belong to.
+ *
+ * @param pathName A string identifier for this registered path.
+ *
+ * @param subFolderName if given then this folder name is appended to every path under
+ * the registered @c pathName before caling @ref GWEN_Directory_GetMatchingFilesRecursively()
+ * on it. You can use this parameter to search only in specific sub folders of the paths.
+ *
+ * @param sl string list to receive the paths of all matching files
+ */
+GWENHYWFAR_API
+int GWEN_PathManager_GetMatchingFilesRecursively(const char *destLib,
+                                                 const char *pathName,
+                                                 const char *subFolderName,
+                                                 GWEN_STRINGLIST *sl,
+                                                 const char *mask);
+
 /*@}*/
 
 #ifdef __cplusplus
