@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: crypttoken.h 1113 2007-01-10 09:14:16Z martin $
-    begin       : Wed Mar 16 2005
-    copyright   : (C) 2005 by Martin Preuss
+    begin       : Mon May 07 2012
+    copyright   : (C) 2012 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -15,6 +12,7 @@
 #define GWEN_CRYPT_KEY_RSA_H
 
 #include "cryptkey.h"
+#include <gwenhywfar/cryptkeyrsa.h>
 
 
 /**
@@ -22,7 +20,7 @@
  * (sig-n) is smaller
  */
 #define GWEN_CRYPT_KEYRSA_FLAGS_DIRECTSIGN 0x00000001
-
+#define GWEN_CRYPT_KEYRSA_FLAGS_ISVERIFIED 0x00000002
 
 #define GWEN_CRYPT_KEYRSA_MAX_KEYLENGTH 1024
 
@@ -40,11 +38,11 @@ extern "C" {
  *  library choose the exponent by its own
  */
 GWENHYWFAR_API int GWEN_Crypt_KeyRsa_GeneratePair(unsigned int nbytes,
-						  int use65537e,
-						  GWEN_CRYPT_KEY **pPubKey,
-						  GWEN_CRYPT_KEY **pSecretKey);
-
+                                                  int use65537e,
+                                                  GWEN_CRYPT_KEY **pPubKey,
+                                                  GWEN_CRYPT_KEY **pSecretKey);
 
+#ifndef NO_DEPRECATED_SYMBOLS
 /**
  * Creates a key pair and returns a pointer to it.
  * This function allows for more precise control over the size of the created key because it
@@ -53,10 +51,14 @@ GWENHYWFAR_API int GWEN_Crypt_KeyRsa_GeneratePair(unsigned int nbytes,
  * @param nbits number of bits
  * @param use65537e !=0: use the value 65537 for the public exponent, otherwise let the
  *  library choose the exponent by its own
+ * @deprecated Please use @ref GWEN_Crypt_KeyRsa_GeneratePair instead since
+ *  nbits should be a multiple of 8 anyway according to Libgcrypt.
  */
-GWENHYWFAR_API int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
-						   GWEN_CRYPT_KEY **pPubKey,
-						   GWEN_CRYPT_KEY **pSecretKey);
+GWENHYWFAR_API GWEN_DEPRECATED
+int GWEN_Crypt_KeyRsa_GeneratePair2(unsigned int nbits, int use65537e,
+                                    GWEN_CRYPT_KEY **pPubKey,
+                                    GWEN_CRYPT_KEY **pSecretKey);
+#endif // ifndef NO_DEPRECATED_SYMBOLS
 
 GWENHYWFAR_API GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_dup(const GWEN_CRYPT_KEY *k);
 
@@ -68,26 +70,23 @@ GWENHYWFAR_API int GWEN_Crypt_KeyRsa_GetExponent(const GWEN_CRYPT_KEY *k, uint8_
 GWENHYWFAR_API int GWEN_Crypt_KeyRsa_GetSecretExponent(const GWEN_CRYPT_KEY *k, uint8_t *buffer, uint32_t *pBufLen);
 
 GWENHYWFAR_API GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModExp(unsigned int nbytes,
-							    const uint8_t *pModulus,
-							    uint32_t lModulus,
-							    const uint8_t *pExponent,
-							    uint32_t lExponent);
+                                                            const uint8_t *pModulus,
+                                                            uint32_t lModulus,
+                                                            const uint8_t *pExponent,
+                                                            uint32_t lExponent);
 
 GWENHYWFAR_API GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModPrivExp(unsigned int nbytes,
-								const uint8_t *pModulus,
-								uint32_t lModulus,
-								const uint8_t *pExponent,
-								uint32_t lExponent,
-								const uint8_t *pPrivExponent,
-								uint32_t lPrivExponent);
+                                                                const uint8_t *pModulus,
+                                                                uint32_t lModulus,
+                                                                const uint8_t *pExponent,
+                                                                uint32_t lExponent,
+                                                                const uint8_t *pPrivExponent,
+                                                                uint32_t lPrivExponent);
 
 GWENHYWFAR_API uint32_t GWEN_Crypt_KeyRsa_GetFlags(const GWEN_CRYPT_KEY *k);
-GWENHYWFAR_API void GWEN_Crypt_KeyRsa_SetFlags(GWEN_CRYPT_KEY *k,
-                                               uint32_t fl);
-GWENHYWFAR_API void GWEN_Crypt_KeyRsa_AddFlags(GWEN_CRYPT_KEY *k,
-                                               uint32_t fl);
-GWENHYWFAR_API void GWEN_Crypt_KeyRsa_SubFlags(GWEN_CRYPT_KEY *k,
-					       uint32_t fl);
+GWENHYWFAR_API void GWEN_Crypt_KeyRsa_SetFlags(GWEN_CRYPT_KEY *k, uint32_t fl);
+GWENHYWFAR_API void GWEN_Crypt_KeyRsa_AddFlags(GWEN_CRYPT_KEY *k, uint32_t fl);
+GWENHYWFAR_API void GWEN_Crypt_KeyRsa_SubFlags(GWEN_CRYPT_KEY *k, uint32_t fl);
 
 #ifdef __cplusplus
 }
