@@ -29,11 +29,12 @@ GWEN_INHERIT(GWEN_CRYPT_KEY, GWEN_CRYPT_KEY_SYM)
 
 
 
-int GWEN_Crypt_KeySym_Encipher(GWEN_CRYPT_KEY *k,
-			       const uint8_t *pInData,
-			       uint32_t inLen,
-			       uint8_t *pOutData,
-			       uint32_t *pOutLen) {
+GWENHYWFAR_CB int GWEN_Crypt_KeySym_Encipher(GWEN_CRYPT_KEY *k,
+                                             const uint8_t *pInData,
+                                             uint32_t inLen,
+                                             uint8_t *pOutData,
+                                             uint32_t *pOutLen)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
 
@@ -53,11 +54,12 @@ int GWEN_Crypt_KeySym_Encipher(GWEN_CRYPT_KEY *k,
 
 
 
-int GWEN_Crypt_KeySym_Decipher(GWEN_CRYPT_KEY *k,
-			       const uint8_t *pInData,
-			       uint32_t inLen,
-			       uint8_t *pOutData,
-			       uint32_t *pOutLen) {
+GWENHYWFAR_CB int GWEN_Crypt_KeySym_Decipher(GWEN_CRYPT_KEY *k,
+                                             const uint8_t *pInData,
+                                             uint32_t inLen,
+                                             uint8_t *pOutData,
+                                             uint32_t *pOutLen)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
 
@@ -77,11 +79,11 @@ int GWEN_Crypt_KeySym_Decipher(GWEN_CRYPT_KEY *k,
 
 
 
-GWENHYWFAR_CB
-void GWEN_Crypt_KeySym_freeData(GWEN_UNUSED void *bp, void *p) {
+GWENHYWFAR_CB void GWEN_Crypt_KeySym_freeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_CRYPT_KEY_SYM *xk;
 
-  xk=(GWEN_CRYPT_KEY_SYM*) p;
+  xk=(GWEN_CRYPT_KEY_SYM *) p;
   if (xk->keyData && xk->keyLen) {
     memset(xk->keyData, 0, xk->keyLen);
     free(xk->keyData);
@@ -95,7 +97,8 @@ void GWEN_Crypt_KeySym_freeData(GWEN_UNUSED void *bp, void *p) {
 
 
 
-GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_dup(const GWEN_CRYPT_KEY *k) {
+GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_dup(const GWEN_CRYPT_KEY *k)
+{
   GWEN_CRYPT_KEY *nk;
   GWEN_CRYPT_KEY_SYM *xk;
 
@@ -105,23 +108,29 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_dup(const GWEN_CRYPT_KEY *k) {
 
   nk=GWEN_Crypt_KeySym_fromData(GWEN_Crypt_Key_GetCryptAlgoId(k),
                                 GWEN_Crypt_Key_GetKeySize(k),
-				xk->mode,
-				xk->algo,
-				GCRY_CIPHER_SECURE,
-				xk->keyData,
-				xk->keyLen);
+                                xk->mode,
+                                xk->algo,
+                                GCRY_CIPHER_SECURE,
+                                xk->keyData,
+                                xk->keyLen);
   return nk;
 }
 
 
 
-enum gcry_cipher_modes GWEN_Crypt_KeySym__MyMode2GMode(GWEN_CRYPT_CRYPTMODE mode) {
-  switch(mode) {
-  case GWEN_Crypt_CryptMode_Unknown: return GCRY_CIPHER_MODE_NONE;
-  case GWEN_Crypt_CryptMode_None:    return GCRY_CIPHER_MODE_NONE;
-  case GWEN_Crypt_CryptMode_Ecb:     return GCRY_CIPHER_MODE_ECB;
-  case GWEN_Crypt_CryptMode_Cfb:     return GCRY_CIPHER_MODE_CFB;
-  case GWEN_Crypt_CryptMode_Cbc:     return GCRY_CIPHER_MODE_CBC;
+enum gcry_cipher_modes GWEN_Crypt_KeySym__MyMode2GMode(GWEN_CRYPT_CRYPTMODE mode)
+{
+  switch (mode) {
+  case GWEN_Crypt_CryptMode_Unknown:
+        return GCRY_CIPHER_MODE_NONE;
+  case GWEN_Crypt_CryptMode_None:
+    return GCRY_CIPHER_MODE_NONE;
+  case GWEN_Crypt_CryptMode_Ecb:
+    return GCRY_CIPHER_MODE_ECB;
+  case GWEN_Crypt_CryptMode_Cfb:
+    return GCRY_CIPHER_MODE_CFB;
+  case GWEN_Crypt_CryptMode_Cbc:
+    return GCRY_CIPHER_MODE_CBC;
   }
 
   return GCRY_CIPHER_MODE_NONE;
@@ -130,10 +139,11 @@ enum gcry_cipher_modes GWEN_Crypt_KeySym__MyMode2GMode(GWEN_CRYPT_CRYPTMODE mode
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_Generate(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, int keySize,
-					   GWEN_CRYPT_CRYPTMODE mode,
-					   int algo,
+                                           GWEN_CRYPT_CRYPTMODE mode,
+                                           int algo,
                                            unsigned int flags,
-					   int quality) {
+                                           int quality)
+{
   GWEN_CRYPT_KEY *k;
   GWEN_CRYPT_KEY_SYM *xk;
   int kbytes;
@@ -148,11 +158,17 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_Generate(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
   GWEN_Crypt_Key_SetEncipherFn(k, GWEN_Crypt_KeySym_Encipher);
   GWEN_Crypt_Key_SetDecipherFn(k, GWEN_Crypt_KeySym_Decipher);
 
-  switch(quality) {
-  case 0:  q=GCRY_WEAK_RANDOM; break;
-  case 1:  q=GCRY_STRONG_RANDOM; break;
+  switch (quality) {
+  case 0:
+    q=GCRY_WEAK_RANDOM;
+    break;
+  case 1:
+    q=GCRY_STRONG_RANDOM;
+    break;
   case 2:
-  default: q=GCRY_VERY_STRONG_RANDOM; break;
+  default:
+    q=GCRY_VERY_STRONG_RANDOM;
+    break;
   }
 
   /* open algo */
@@ -165,7 +181,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_Generate(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
   xk->algoValid=1;
   xk->mode=mode;
 
-  while(1) {
+  while (1) {
     kbytes=keySize;
     keyData=gcry_random_bytes(kbytes, q);
 
@@ -177,12 +193,12 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_Generate(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
     err=gcry_cipher_setkey(xk->algoHandle, xk->keyData, xk->keyLen);
     if (err) {
       if ((err & GPG_ERR_CODE_MASK)==GPG_ERR_WEAK_KEY) {
-	DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_setkey(): weak key, will try again");
+        DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_setkey(): weak key, will try again");
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_setkey(): %d [%s]", err, gcry_strerror(err));
-	GWEN_Crypt_Key_free(k);
-	return NULL;
+        DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_setkey(): %d [%s]", err, gcry_strerror(err));
+        GWEN_Crypt_Key_free(k);
+        return NULL;
       }
     }
     else
@@ -201,10 +217,11 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_Generate(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromData(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, int keySize,
-					   GWEN_CRYPT_CRYPTMODE mode,
-					   int algo,
-					   unsigned int flags,
-					   const uint8_t *kd, uint32_t kl) {
+                                           GWEN_CRYPT_CRYPTMODE mode,
+                                           int algo,
+                                           unsigned int flags,
+                                           const uint8_t *kd, uint32_t kl)
+{
   GWEN_CRYPT_KEY *k;
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
@@ -212,7 +229,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromData(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
 #if 0
   if (kl!=gcry_cipher_get_algo_keylen(algo)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Invalid key length (is %d, should be %d)",
-	      (int)kl, (int)gcry_cipher_get_algo_keylen(algo));
+              (int)kl, (int)gcry_cipher_get_algo_keylen(algo));
     return NULL;
   }
 #endif
@@ -243,7 +260,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromData(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
   }
 
   /* store key data */
-  xk->keyData=(uint8_t*) malloc(kl);
+  xk->keyData=(uint8_t *) malloc(kl);
   assert(xk->keyData);
   memmove(xk->keyData, kd, kl);
   xk->keyLen=kl;
@@ -262,15 +279,16 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromData(GWEN_CRYPT_CRYPTALGOID cryptAlgoId, i
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeySym__fromDb(GWEN_CRYPT_CRYPTALGOID cryptAlgoId,
-					  GWEN_CRYPT_CRYPTMODE mode,
-					  int algo,
-					  unsigned int flags,
-					  const char *gname,
-					  GWEN_DB_NODE *db) {
+                                          GWEN_CRYPT_CRYPTMODE mode,
+                                          int algo,
+                                          unsigned int flags,
+                                          const char *gname,
+                                          GWEN_DB_NODE *db)
+{
   gcry_error_t err;
   GWEN_CRYPT_KEY *k;
   GWEN_CRYPT_KEY_SYM *xk;
-  unsigned int nbits;
+  //unsigned int nbits;
   GWEN_DB_NODE *dbR;
   unsigned int len;
   const char *p;
@@ -278,7 +296,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym__fromDb(GWEN_CRYPT_CRYPTALGOID cryptAlgoId,
   dbR=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, gname);
   if (dbR==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN, "DB does not contain an %s key (no %s group)",
-	      gname, gname);
+              gname, gname);
     return NULL;
   }
 
@@ -292,7 +310,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym__fromDb(GWEN_CRYPT_CRYPTALGOID cryptAlgoId,
     GWEN_Crypt_Key_free(k);
     return NULL;
   }
-  nbits=GWEN_Crypt_Key_GetKeySize(k)*8;
+  //nbits=GWEN_Crypt_Key_GetKeySize(k)*8;
 
   /* extend key */
   GWEN_NEW_OBJECT(GWEN_CRYPT_KEY_SYM, xk);
@@ -320,7 +338,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym__fromDb(GWEN_CRYPT_CRYPTALGOID cryptAlgoId,
   }
 
   /* store key data */
-  xk->keyData=(uint8_t*) malloc(len);
+  xk->keyData=(uint8_t *) malloc(len);
   assert(xk->keyData);
   memmove(xk->keyData, p, len);
   xk->keyLen=len;
@@ -338,7 +356,8 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym__fromDb(GWEN_CRYPT_CRYPTALGOID cryptAlgoId,
 
 
 
-int GWEN_Crypt_KeySym__toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db, const char *gname) {
+int GWEN_Crypt_KeySym__toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db, const char *gname)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   GWEN_DB_NODE *dbR;
   int rv;
@@ -357,18 +376,19 @@ int GWEN_Crypt_KeySym__toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db, const cha
   assert(dbR);
 
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "keyData", xk->keyData, xk->keyLen);
+                      "keyData", xk->keyData, xk->keyLen);
 
   return 0;
 }
 
 
 
-GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE *db) {
+GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE *db)
+{
   gcry_error_t err;
   GWEN_CRYPT_KEY *k;
   GWEN_CRYPT_KEY_SYM *xk;
-  unsigned int nbits;
+  //unsigned int nbits;
   GWEN_DB_NODE *dbR;
   unsigned int len;
   const char *gname;
@@ -385,12 +405,12 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE
   dbR=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST, gname);
   if (dbR==NULL) {
     DBG_ERROR(GWEN_LOGDOMAIN, "DB does not contain an %s key (no %s group)",
-	      gname, gname);
+              gname, gname);
     GWEN_Crypt_Key_free(k);
     return NULL;
   }
 
-  nbits=GWEN_Crypt_Key_GetKeySize(k)*8;
+  //nbits=GWEN_Crypt_Key_GetKeySize(k)*8;
 
   /* extend key */
   GWEN_NEW_OBJECT(GWEN_CRYPT_KEY_SYM, xk);
@@ -400,9 +420,9 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE
 
   /* open algo */
   err=gcry_cipher_open(&xk->algoHandle,
-		       GWEN_Crypt_Key_GetCryptAlgoId(k),
-		       GWEN_Crypt_KeySym__MyMode2GMode(mode),
-		       GCRY_CIPHER_SECURE);
+                       GWEN_Crypt_Key_GetCryptAlgoId(k),
+                       GWEN_Crypt_KeySym__MyMode2GMode(mode),
+                       GCRY_CIPHER_SECURE);
   if (err) {
     DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_open(): %s", gcry_strerror(err));
     GWEN_Crypt_Key_free(k);
@@ -421,7 +441,7 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE
   }
 
   /* store key data */
-  xk->keyData=(uint8_t*) malloc(len);
+  xk->keyData=(uint8_t *) malloc(len);
   assert(xk->keyData);
   memmove(xk->keyData, p, len);
   xk->keyLen=len;
@@ -439,7 +459,8 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeySym_fromDb(GWEN_CRYPT_CRYPTMODE mode, GWEN_DB_NODE
 
 
 
-int GWEN_Crypt_KeySym_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db) {
+int GWEN_Crypt_KeySym_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   GWEN_DB_NODE *dbR;
   int rv;
@@ -461,14 +482,15 @@ int GWEN_Crypt_KeySym_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db) {
   assert(dbR);
 
   GWEN_DB_SetBinValue(dbR, GWEN_DB_FLAGS_OVERWRITE_VARS,
-		      "keyData", xk->keyData, xk->keyLen);
+                      "keyData", xk->keyData, xk->keyLen);
 
   return 0;
 }
 
 
 
-int GWEN_Crypt_KeySym_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl) {
+int GWEN_Crypt_KeySym_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
 
@@ -487,7 +509,7 @@ int GWEN_Crypt_KeySym_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t
   }
 
   /* store key data */
-  xk->keyData=(uint8_t*)malloc(kl);
+  xk->keyData=(uint8_t *)malloc(kl);
   assert(xk->keyData);
   memmove(xk->keyData, kd, kl);
   xk->keyLen=kl;
@@ -505,7 +527,8 @@ int GWEN_Crypt_KeySym_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t
 
 
 
-uint8_t *GWEN_Crypt_KeySym_GetKeyDataPtr(const GWEN_CRYPT_KEY *k) {
+uint8_t *GWEN_Crypt_KeySym_GetKeyDataPtr(const GWEN_CRYPT_KEY *k)
+{
   GWEN_CRYPT_KEY_SYM *xk;
 
   assert(k);
@@ -517,7 +540,8 @@ uint8_t *GWEN_Crypt_KeySym_GetKeyDataPtr(const GWEN_CRYPT_KEY *k) {
 
 
 
-uint32_t GWEN_Crypt_KeySym_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
+uint32_t GWEN_Crypt_KeySym_GetKeyDataLen(const GWEN_CRYPT_KEY *k)
+{
   GWEN_CRYPT_KEY_SYM *xk;
 
   assert(k);
@@ -531,8 +555,9 @@ uint32_t GWEN_Crypt_KeySym_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyDes3K_Generate(GWEN_CRYPT_CRYPTMODE mode,
-					     int keySize,
-					     int quality){
+                                             int keySize,
+                                             int quality)
+{
   uint8_t kd[16];
   GWEN_CRYPT_KEY *k;
 
@@ -546,7 +571,8 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyDes3K_Generate(GWEN_CRYPT_CRYPTMODE mode,
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyDes3K_fromData(GWEN_CRYPT_CRYPTMODE mode, int keySize,
-					     const uint8_t *kd, uint32_t kl) {
+                                             const uint8_t *kd, uint32_t kl)
+{
   if (kl==16) {
     uint8_t new_kd[24];
     GWEN_CRYPT_KEY *k;
@@ -555,32 +581,35 @@ GWEN_CRYPT_KEY *GWEN_Crypt_KeyDes3K_fromData(GWEN_CRYPT_CRYPTMODE mode, int keyS
     memmove(new_kd, kd, 16);
     memmove(new_kd+16, new_kd, 8);
     k=GWEN_Crypt_KeySym_fromData(GWEN_Crypt_CryptAlgoId_Des3K, 24,
-				 mode, GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, new_kd, 24);
+                                 mode, GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, new_kd, 24);
     memset(new_kd, 0, 24);
     return k;
   }
   else
     return GWEN_Crypt_KeySym_fromData(GWEN_Crypt_CryptAlgoId_Des3K, keySize,
-				      mode, GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, kd, kl);
+                                      mode, GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, kd, kl);
 }
 
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyDes3K_fromDb(GWEN_CRYPT_CRYPTMODE mode,
-					   GWEN_DB_NODE *db) {
+                                           GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__fromDb(GWEN_Crypt_CryptAlgoId_Des3K, mode,
-				   GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, "des3k", db);
+                                   GCRY_CIPHER_3DES, GCRY_CIPHER_SECURE, "des3k", db);
 }
 
 
 
-int GWEN_Crypt_KeyDes3K_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db) {
+int GWEN_Crypt_KeyDes3K_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__toDb(k, db, "des3k");
 }
 
 
 
-int GWEN_Crypt_KeyDes3K_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl) {
+int GWEN_Crypt_KeyDes3K_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl)
+{
   if (kl==16) {
     uint8_t new_kd[24];
     int rv;
@@ -598,21 +627,24 @@ int GWEN_Crypt_KeyDes3K_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_
 
 
 
-uint8_t *GWEN_Crypt_KeyDes3K_GetKeyDataPtr(const GWEN_CRYPT_KEY *k) {
+uint8_t *GWEN_Crypt_KeyDes3K_GetKeyDataPtr(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataPtr(k);
 }
 
 
 
-uint32_t GWEN_Crypt_KeyDes3K_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
+uint32_t GWEN_Crypt_KeyDes3K_GetKeyDataLen(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataLen(k);
 }
 
 
 
 int GWEN_Crypt_KeyDes3K_SetIV(GWEN_CRYPT_KEY *k,
-			      const uint8_t *kd,
-			      uint32_t kl) {
+                              const uint8_t *kd,
+                              uint32_t kl)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
 
@@ -621,7 +653,7 @@ int GWEN_Crypt_KeyDes3K_SetIV(GWEN_CRYPT_KEY *k,
   assert(xk);
 
   if (kd==NULL || kl==0) {
-    const uint8_t iv[]={
+    const uint8_t iv[]= {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
     };
     err=gcry_cipher_setiv(xk->algoHandle, iv, sizeof(iv));
@@ -643,50 +675,57 @@ int GWEN_Crypt_KeyDes3K_SetIV(GWEN_CRYPT_KEY *k,
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyBlowFish_Generate(GWEN_CRYPT_CRYPTMODE mode,
-						int keySize,
-						int quality){
+                                                int keySize,
+                                                int quality)
+{
   return GWEN_Crypt_KeySym_Generate(GWEN_Crypt_CryptAlgoId_BlowFish, keySize, mode,
-				    GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE, quality);
+                                    GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE, quality);
 }
 
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyBlowFish_fromData(GWEN_CRYPT_CRYPTMODE mode, int keySize,
-						const uint8_t *kd, uint32_t kl) {
+                                                const uint8_t *kd, uint32_t kl)
+{
   return GWEN_Crypt_KeySym_fromData(GWEN_Crypt_CryptAlgoId_BlowFish, keySize, mode,
-				    GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE,
-				    kd, kl);
+                                    GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE,
+                                    kd, kl);
 }
 
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyBlowFish_fromDb(GWEN_CRYPT_CRYPTMODE mode,
-					      GWEN_DB_NODE *db) {
+                                              GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__fromDb(GWEN_Crypt_CryptAlgoId_BlowFish, mode,
-				   GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE, "blowFish", db);
+                                   GCRY_CIPHER_BLOWFISH, GCRY_CIPHER_SECURE, "blowFish", db);
 }
 
 
 
-int GWEN_Crypt_KeyBlowFish_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db) {
+int GWEN_Crypt_KeyBlowFish_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__toDb(k, db, "blowFish");
 }
 
 
 
-int GWEN_Crypt_KeyBlowFish_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl) {
+int GWEN_Crypt_KeyBlowFish_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl)
+{
   return GWEN_Crypt_KeySym_SetKeyData(k, kd, kl);
 }
 
 
 
-uint8_t *GWEN_Crypt_KeyBlowFish_GetKeyDataPtr(const GWEN_CRYPT_KEY *k) {
+uint8_t *GWEN_Crypt_KeyBlowFish_GetKeyDataPtr(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataPtr(k);
 }
 
 
 
-uint32_t GWEN_Crypt_KeyBlowFish_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
+uint32_t GWEN_Crypt_KeyBlowFish_GetKeyDataLen(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataLen(k);
 }
 
@@ -694,58 +733,66 @@ uint32_t GWEN_Crypt_KeyBlowFish_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes128_Generate(GWEN_CRYPT_CRYPTMODE mode,
-					      int keySize,
-					      int quality){
+                                              int keySize,
+                                              int quality)
+{
   return GWEN_Crypt_KeySym_Generate(GWEN_Crypt_CryptAlgoId_Aes128, keySize, mode,
-				    GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE, quality);
+                                    GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE, quality);
 }
 
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes128_fromData(GWEN_CRYPT_CRYPTMODE mode, int keySize,
-					      const uint8_t *kd, uint32_t kl) {
+                                              const uint8_t *kd, uint32_t kl)
+{
   return GWEN_Crypt_KeySym_fromData(GWEN_Crypt_CryptAlgoId_Aes128, keySize, mode,
-				    GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE,
-				    kd, kl);
+                                    GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE,
+                                    kd, kl);
 }
 
 
 
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes128_fromDb(GWEN_CRYPT_CRYPTMODE mode,
-					    GWEN_DB_NODE *db) {
+                                            GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__fromDb(GWEN_Crypt_CryptAlgoId_Aes128, mode,
-				   GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE, "aes128", db);
+                                   GCRY_CIPHER_AES128, GCRY_CIPHER_SECURE, "aes128", db);
 }
 
 
 
-int GWEN_Crypt_KeyAes128_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db) {
+int GWEN_Crypt_KeyAes128_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db)
+{
   return GWEN_Crypt_KeySym__toDb(k, db, "aes128");
 }
 
 
 
-int GWEN_Crypt_KeyAes128_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl) {
+int GWEN_Crypt_KeyAes128_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl)
+{
   return GWEN_Crypt_KeySym_SetKeyData(k, kd, kl);
 }
 
 
 
-uint8_t *GWEN_Crypt_KeyAes128_GetKeyDataPtr(const GWEN_CRYPT_KEY *k) {
+uint8_t *GWEN_Crypt_KeyAes128_GetKeyDataPtr(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataPtr(k);
 }
 
 
 
-uint32_t GWEN_Crypt_KeyAes128_GetKeyDataLen(const GWEN_CRYPT_KEY *k) {
+uint32_t GWEN_Crypt_KeyAes128_GetKeyDataLen(const GWEN_CRYPT_KEY *k)
+{
   return GWEN_Crypt_KeySym_GetKeyDataLen(k);
 }
 
 
 
 int GWEN_Crypt_KeyAes128_SetIV(GWEN_CRYPT_KEY *k,
-			       const uint8_t *kd,
-			       uint32_t kl) {
+                               const uint8_t *kd,
+                               uint32_t kl)
+{
   GWEN_CRYPT_KEY_SYM *xk;
   gcry_error_t err;
 
@@ -754,7 +801,92 @@ int GWEN_Crypt_KeyAes128_SetIV(GWEN_CRYPT_KEY *k,
   assert(xk);
 
   if (kd==NULL || kl==0) {
-    const uint8_t iv[]={
+    const uint8_t iv[]= {
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
+    };
+    err=gcry_cipher_setiv(xk->algoHandle, iv, sizeof(iv));
+  }
+  else
+    err=gcry_cipher_setiv(xk->algoHandle, kd, kl);
+  if (err) {
+    DBG_INFO(GWEN_LOGDOMAIN, "gcry_cipher_setiv(): %s", gcry_strerror(err));
+    return GWEN_ERROR_GENERIC;
+  }
+
+  return 0;
+}
+
+
+
+GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes256_Generate(GWEN_CRYPT_CRYPTMODE mode,
+                                              int keySize,
+                                              int quality)
+{
+  return GWEN_Crypt_KeySym_Generate(GWEN_Crypt_CryptAlgoId_Aes256, keySize, mode,
+                                    GCRY_CIPHER_AES256, GCRY_CIPHER_SECURE, quality);
+}
+
+
+
+GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes256_fromData(GWEN_CRYPT_CRYPTMODE mode, int keySize,
+                                              const uint8_t *kd, uint32_t kl)
+{
+  return GWEN_Crypt_KeySym_fromData(GWEN_Crypt_CryptAlgoId_Aes256, keySize, mode,
+                                    GCRY_CIPHER_AES256, GCRY_CIPHER_SECURE,
+                                    kd, kl);
+}
+
+
+
+GWEN_CRYPT_KEY *GWEN_Crypt_KeyAes256_fromDb(GWEN_CRYPT_CRYPTMODE mode,
+                                            GWEN_DB_NODE *db)
+{
+  return GWEN_Crypt_KeySym__fromDb(GWEN_Crypt_CryptAlgoId_Aes256, mode,
+                                   GCRY_CIPHER_AES256, GCRY_CIPHER_SECURE, "aes256", db);
+}
+
+
+
+int GWEN_Crypt_KeyAes256_toDb(const GWEN_CRYPT_KEY *k, GWEN_DB_NODE *db)
+{
+  return GWEN_Crypt_KeySym__toDb(k, db, "aes256");
+}
+
+
+
+int GWEN_Crypt_KeyAes256_SetKeyData(GWEN_CRYPT_KEY *k, const uint8_t *kd, uint32_t kl)
+{
+  return GWEN_Crypt_KeySym_SetKeyData(k, kd, kl);
+}
+
+
+
+uint8_t *GWEN_Crypt_KeyAes256_GetKeyDataPtr(const GWEN_CRYPT_KEY *k)
+{
+  return GWEN_Crypt_KeySym_GetKeyDataPtr(k);
+}
+
+
+
+uint32_t GWEN_Crypt_KeyAes256_GetKeyDataLen(const GWEN_CRYPT_KEY *k)
+{
+  return GWEN_Crypt_KeySym_GetKeyDataLen(k);
+}
+
+int GWEN_Crypt_KeyAes256_SetIV(GWEN_CRYPT_KEY *k,
+                               const uint8_t *kd,
+                               uint32_t kl)
+{
+  GWEN_CRYPT_KEY_SYM *xk;
+  gcry_error_t err;
+
+  assert(k);
+  xk=GWEN_INHERIT_GETDATA(GWEN_CRYPT_KEY, GWEN_CRYPT_KEY_SYM, k);
+  assert(xk);
+
+  if (kd==NULL || kl==0) {
+    const uint8_t iv[]= {
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
       0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00
     };
@@ -774,8 +906,3 @@ int GWEN_Crypt_KeyAes128_SetIV(GWEN_CRYPT_KEY *k,
 
 
 
-
-
-
-
-
