@@ -31,22 +31,24 @@ GWEN_INHERIT(GWEN_CRYPTMGR, GWEN_CRYPTMGR_KEYS);
 
 
 GWEN_CRYPTMGR *GWEN_CryptMgrKeys_new(const char *localName,
-				     GWEN_CRYPT_KEY *localKey,
-				     const char *peerName,
-				     GWEN_CRYPT_KEY *peerKey,
-				     int ownKeys) {
+                                     GWEN_CRYPT_KEY *localKey,
+                                     const char *peerName,
+                                     GWEN_CRYPT_KEY *peerKey,
+                                     int ownKeys)
+{
   GWEN_CRYPTMGR *cm;
   GWEN_CRYPTMGR_KEYS *xcm;
 
   cm=GWEN_CryptMgr_new();
   GWEN_NEW_OBJECT(GWEN_CRYPTMGR_KEYS, xcm);
   GWEN_INHERIT_SETDATA(GWEN_CRYPTMGR, GWEN_CRYPTMGR_KEYS, cm, xcm,
-		       GWEN_CryptMgrKeys_FreeData);
+                       GWEN_CryptMgrKeys_FreeData);
 
   if (localKey) {
     xcm->localKey=localKey;
     GWEN_CryptMgr_SetLocalKeyNumber(cm, GWEN_Crypt_Key_GetKeyNumber(localKey));
     GWEN_CryptMgr_SetLocalKeyVersion(cm, GWEN_Crypt_Key_GetKeyVersion(localKey));
+    xcm->ownLocalKey=ownKeys;
   }
   else
     xcm->ownLocalKey=0;
@@ -77,10 +79,11 @@ GWEN_CRYPTMGR *GWEN_CryptMgrKeys_new(const char *localName,
 
 
 GWENHYWFAR_CB
-void GWEN_CryptMgrKeys_FreeData(GWEN_UNUSED void *bp, void *p) {
+void GWEN_CryptMgrKeys_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
 
-  xcm=(GWEN_CRYPTMGR_KEYS*) p;
+  xcm=(GWEN_CRYPTMGR_KEYS *) p;
 
   if (xcm->ownLocalKey)
     GWEN_Crypt_Key_free(xcm->localKey);
@@ -91,8 +94,9 @@ void GWEN_CryptMgrKeys_FreeData(GWEN_UNUSED void *bp, void *p) {
 
 
 void GWEN_CryptMgrKeys_SetPeerKey(GWEN_CRYPTMGR *cm,
-				  GWEN_CRYPT_KEY *peerKey,
-				  int ownKey) {
+                                  GWEN_CRYPT_KEY *peerKey,
+                                  int ownKey)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
 
   assert(cm);
@@ -109,8 +113,9 @@ void GWEN_CryptMgrKeys_SetPeerKey(GWEN_CRYPTMGR *cm,
 
 GWENHYWFAR_CB
 int GWEN_CryptMgrKeys_SignData(GWEN_CRYPTMGR *cm,
-			       const uint8_t *pData, uint32_t lData,
-			       GWEN_BUFFER *dbuf) {
+                               const uint8_t *pData, uint32_t lData,
+                               GWEN_BUFFER *dbuf)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
   GWEN_MDIGEST *md;
   int rv;
@@ -153,8 +158,8 @@ int GWEN_CryptMgrKeys_SignData(GWEN_CRYPTMGR *cm,
   /* padd */
   tbuf=GWEN_Buffer_new(0, ksize, 0, 1);
   GWEN_Buffer_AppendBytes(tbuf,
-			  (const char*)GWEN_MDigest_GetDigestPtr(md),
-			  GWEN_MDigest_GetDigestSize(md));
+                          (const char *)GWEN_MDigest_GetDigestPtr(md),
+                          GWEN_MDigest_GetDigestSize(md));
   GWEN_MDigest_free(md);
   GWEN_Padd_PaddWithIso9796_2(tbuf, ksize);
 
@@ -162,10 +167,10 @@ int GWEN_CryptMgrKeys_SignData(GWEN_CRYPTMGR *cm,
   GWEN_Buffer_AllocRoom(dbuf, ksize);
   signatureLen=GWEN_Buffer_GetMaxUnsegmentedWrite(dbuf);
   rv=GWEN_Crypt_Key_Sign(xcm->localKey,
-			 (uint8_t*)GWEN_Buffer_GetStart(tbuf),
-			 GWEN_Buffer_GetUsedBytes(tbuf),
-			 (uint8_t*)GWEN_Buffer_GetPosPointer(dbuf),
-			 &signatureLen);
+                         (uint8_t *)GWEN_Buffer_GetStart(tbuf),
+                         GWEN_Buffer_GetUsedBytes(tbuf),
+                         (uint8_t *)GWEN_Buffer_GetPosPointer(dbuf),
+                         &signatureLen);
   GWEN_Buffer_free(tbuf);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -182,8 +187,9 @@ int GWEN_CryptMgrKeys_SignData(GWEN_CRYPTMGR *cm,
 
 GWENHYWFAR_CB
 int GWEN_CryptMgrKeys_VerifyData(GWEN_CRYPTMGR *cm,
-				 const uint8_t *pData, uint32_t lData,
-				 const uint8_t *pSignature, uint32_t lSignature) {
+                                 const uint8_t *pData, uint32_t lData,
+                                 const uint8_t *pSignature, uint32_t lSignature)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
   GWEN_MDIGEST *md;
   int rv;
@@ -208,9 +214,9 @@ int GWEN_CryptMgrKeys_VerifyData(GWEN_CRYPTMGR *cm,
   tbuf=GWEN_Buffer_new(0, ksize+16, 0, 1);
   l=GWEN_Buffer_GetMaxUnsegmentedWrite(tbuf);
   rv=GWEN_Crypt_Key_Encipher(xcm->peerKey,
-			     pSignature, lSignature,
-			     (uint8_t*)GWEN_Buffer_GetPosPointer(tbuf),
-			     &l);
+                             pSignature, lSignature,
+                             (uint8_t *)GWEN_Buffer_GetPosPointer(tbuf),
+                             &l);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(tbuf);
@@ -261,7 +267,7 @@ int GWEN_CryptMgrKeys_VerifyData(GWEN_CRYPTMGR *cm,
 
   if (memcmp(GWEN_MDigest_GetDigestPtr(md),
              GWEN_Buffer_GetStart(tbuf),
-	     GWEN_MDigest_GetDigestSize(md))!=0) {
+             GWEN_MDigest_GetDigestSize(md))!=0) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Invalid signature");
     GWEN_MDigest_free(md);
     GWEN_Buffer_free(tbuf);
@@ -278,8 +284,9 @@ int GWEN_CryptMgrKeys_VerifyData(GWEN_CRYPTMGR *cm,
 
 GWENHYWFAR_CB
 int GWEN_CryptMgrKeys_EncryptKey(GWEN_CRYPTMGR *cm,
-				 const uint8_t *pData, uint32_t lData,
-				 GWEN_BUFFER *dbuf) {
+                                 const uint8_t *pData, uint32_t lData,
+                                 GWEN_BUFFER *dbuf)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
   int rv;
   GWEN_BUFFER *tbuf;
@@ -299,7 +306,7 @@ int GWEN_CryptMgrKeys_EncryptKey(GWEN_CRYPTMGR *cm,
 
   /* padd key data */
   tbuf=GWEN_Buffer_new(0, ksize, 0, 1);
-  GWEN_Buffer_AppendBytes(tbuf, (const char*) pData, lData);
+  GWEN_Buffer_AppendBytes(tbuf, (const char *) pData, lData);
   rv=GWEN_Padd_PaddWithIso9796_2(tbuf, ksize);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -310,10 +317,10 @@ int GWEN_CryptMgrKeys_EncryptKey(GWEN_CRYPTMGR *cm,
   GWEN_Buffer_AllocRoom(dbuf, ksize);
   l=GWEN_Buffer_GetMaxUnsegmentedWrite(dbuf);
   rv=GWEN_Crypt_Key_Encipher(xcm->peerKey,
-			     (const uint8_t*)GWEN_Buffer_GetStart(tbuf),
-			     GWEN_Buffer_GetUsedBytes(tbuf),
-			     (uint8_t*)GWEN_Buffer_GetPosPointer(dbuf),
-			     &l);
+                             (const uint8_t *)GWEN_Buffer_GetStart(tbuf),
+                             GWEN_Buffer_GetUsedBytes(tbuf),
+                             (uint8_t *)GWEN_Buffer_GetPosPointer(dbuf),
+                             &l);
   GWEN_Buffer_free(tbuf);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -330,8 +337,9 @@ int GWEN_CryptMgrKeys_EncryptKey(GWEN_CRYPTMGR *cm,
 
 GWENHYWFAR_CB
 int GWEN_CryptMgrKeys_DecryptKey(GWEN_CRYPTMGR *cm,
-				 const uint8_t *pData, uint32_t lData,
-				 GWEN_BUFFER *dbuf) {
+                                 const uint8_t *pData, uint32_t lData,
+                                 GWEN_BUFFER *dbuf)
+{
   GWEN_CRYPTMGR_KEYS *xcm;
   int rv;
   GWEN_BUFFER *tbuf;
@@ -352,9 +360,9 @@ int GWEN_CryptMgrKeys_DecryptKey(GWEN_CRYPTMGR *cm,
   tbuf=GWEN_Buffer_new(0, ksize, 0, 1);
   l=GWEN_Buffer_GetMaxUnsegmentedWrite(tbuf);
   rv=GWEN_Crypt_Key_Decipher(xcm->localKey,
-			     pData, lData,
-			     (uint8_t*)GWEN_Buffer_GetPosPointer(tbuf),
-			     &l);
+                             pData, lData,
+                             (uint8_t *)GWEN_Buffer_GetPosPointer(tbuf),
+                             &l);
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(tbuf);
