@@ -37,16 +37,16 @@
 # define GWEN_UNUSED
 #else
 # ifdef BUILDING_GWENHYWFAR
-   /* building Gwenhywfar */
+/* building Gwenhywfar */
 #  if GWENHYWFAR_SYS_IS_WINDOWS
-     /* for windows */
+/* for windows */
 #    ifdef __declspec
 #      define GWENHYWFAR_API __declspec (dllexport)
 #    else /* if __declspec */
 #      define GWENHYWFAR_API
 #    endif /* if NOT __declspec */
 #  else
-     /* for non-win32 */
+/* for non-win32 */
 #    ifdef GCC_WITH_VISIBILITY_ATTRIBUTE
 #      define GWENHYWFAR_API __attribute__((visibility("default")))
 #    else
@@ -54,16 +54,16 @@
 #    endif
 #  endif
 # else
-   /* not building Gwenhywfar */
+/* not building Gwenhywfar */
 #  if GWENHYWFAR_SYS_IS_WINDOWS
-     /* for windows */
+/* for windows */
 #    ifdef __declspec
 #      define GWENHYWFAR_API __declspec (dllimport)
 #    else /* if __declspec */
 #      define GWENHYWFAR_API
 #    endif /* if NOT __declspec */
 #  else
-     /* for non-win32 */
+/* for non-win32 */
 #    define GWENHYWFAR_API
 #  endif
 # endif
@@ -90,8 +90,13 @@
 #endif
 
 #if GWENHYWFAR_SYS_IS_WINDOWS
+#ifdef __MINGW32__
+# define GWEN_DIR_SEPARATOR           '/'
+# define GWEN_DIR_SEPARATOR_S         "/"
+#else
 # define GWEN_DIR_SEPARATOR           '\\'
 # define GWEN_DIR_SEPARATOR_S         "\\"
+#endif
 # define GWEN_SEARCHPATH_SEPARATOR    ';'
 # define GWEN_SEARCHPATH_SEPARATOR_S  ";"
 #else
@@ -136,16 +141,26 @@
 
 #if __GNUC_PREREQ(3, 0)
 /* Only available in gcc >= 3.0.x */
-# define DEPRECATED __attribute__((deprecated))
+# define GWEN_DEPRECATED __attribute__((deprecated))
+# define GWEN_UNUSED __attribute__((unused))
 # define GWEN_LIKELY(cond) __builtin_expect(!!(cond), 1)
 # define GWEN_UNLIKELY(cond) __builtin_expect(!!(cond), 0)
 #else
-# define DEPRECATED
+# define GWEN_DEPRECATED
+# define GWEN_UNUSED
 # define GWEN_LIKELY(cond) (!!(cond))
 # define GWEN_UNLIKELY(cond) (!!(cond))
 #endif /* __GNUC__ */
 
 
+#if defined(__GNUC__) && !defined(__MINGW32__)
+# define GWEN_FORMAT(fmt, pos, argstart)  \
+  __attribute__ ((format (fmt, pos, argstart)))
+#else
+# define GWEN_FORMAT(fmt, pos, argstart)
+#endif
+
+
 #define GWEN_TIMEOUT_NONE    (0)
 #define GWEN_TIMEOUT_FOREVER (-1)
 
