@@ -34,12 +34,12 @@
 
 
 
-GWEN_SEMAPHORE *GWEN_Semaphore_new(void)
+GWEN_SEMAPHORE *GWEN_Semaphore_new(int initialCount)
 {
   GWEN_SEMAPHORE *sm;
 
   GWEN_NEW_OBJECT(GWEN_SEMAPHORE, sm);
-  sm->semId=CreateSemaphore(NULL, 0, 0x7fffffff, NULL);
+  sm->semId=CreateSemaphore(NULL, initialCount, 0x7fffffff, NULL);
   return sm;
 }
 
@@ -55,18 +55,22 @@ void GWEN_Semaphore_free(GWEN_SEMAPHORE *sm)
 
 
 
-void GWEN_Semaphore_Wait(GWEN_SEMAPHORE *sm)
+int GWEN_Semaphore_Wait(GWEN_SEMAPHORE *sm)
 {
   assert(sm);
   WaitForSingleObject(sm->semId, INFINITE);
+  /* TODO: check for error */
+  return 0;
 }
 
 
 
-void GWEN_Semaphore_Post(GWEN_SEMAPHORE *sm)
+int GWEN_Semaphore_Post(GWEN_SEMAPHORE *sm)
 {
   assert(sm);
   ReleaseSemaphore(sm->semId, 1, NULL);
+  /* TODO: check for error */
+  return 0;
 }
 
 
