@@ -43,7 +43,8 @@ static const char GWEN_Base64_Alphabet[]=
 
 int GWEN_Base64_Encode(const unsigned char *src, unsigned int size,
                        GWEN_BUFFER *dst,
-                       unsigned int maxLineLength) {
+                       unsigned int maxLineLength)
+{
   unsigned int by3;
   unsigned int i;
   unsigned int l;
@@ -90,7 +91,7 @@ int GWEN_Base64_Encode(const unsigned char *src, unsigned int size,
   }
 
   /* then encode remainder */
-  switch(size % 3) {
+  switch (size % 3) {
   case 0:
     /* no remainder */
     break;
@@ -130,7 +131,8 @@ int GWEN_Base64_Encode(const unsigned char *src, unsigned int size,
 
 
 int GWEN_Base64_Decode(const unsigned char *src, unsigned int size,
-                       GWEN_BUFFER *dst) {
+                       GWEN_BUFFER *dst)
+{
   unsigned int i;
   const char *p = "0";
   uint32_t v;
@@ -152,8 +154,8 @@ int GWEN_Base64_Decode(const unsigned char *src, unsigned int size,
     for (i=0; i<4; i++) {
       /* get next valid character */
       if (lastWasEq) {
-	while (*src && *src!='=')
-	  src++;
+        while (*src && *src!='=')
+          src++;
       }
       else {
         while (*src && ((p=strchr(GWEN_Base64_Alphabet, *src))==0))
@@ -177,7 +179,7 @@ int GWEN_Base64_Decode(const unsigned char *src, unsigned int size,
 
     /* now we have a triplet */
     if (sizeGiven) {
-      switch(size) {
+      switch (size) {
       case 1:
         GWEN_Buffer_AppendByte(dst, (v>>16) & 0xff);
         size--;
@@ -200,12 +202,12 @@ int GWEN_Base64_Decode(const unsigned char *src, unsigned int size,
 
       bytes=(24-(lastWasEq*6))/8;
       if (bytes) {
-	GWEN_Buffer_AppendByte(dst, (v>>16) & 0xff);
-	if (bytes>1) {
-	  GWEN_Buffer_AppendByte(dst, (v>>8) & 0xff);
+        GWEN_Buffer_AppendByte(dst, (v>>16) & 0xff);
+        if (bytes>1) {
+          GWEN_Buffer_AppendByte(dst, (v>>8) & 0xff);
           if (bytes>2)
-	    GWEN_Buffer_AppendByte(dst, v & 0xff);
-	}
+            GWEN_Buffer_AppendByte(dst, v & 0xff);
+        }
       }
     }
   } /* for full quadruplets */
