@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id$
  begin       : Tue Sep 09 2003
- copyright   : (C) 2003 by Martin Preuss
+ copyright   : (C) 2003-2010 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -180,11 +177,11 @@ extern "C" {
 
 
 
-typedef void* (*GWEN_PATHHANDLERPTR)(const char *entry,
+typedef void *(*GWEN_PATHHANDLERPTR)(const char *entry,
                                      void *data,
                                      uint32_t flags);
 
-typedef void* (*GWEN_PATHIDXHANDLERPTR)(const char *entry,
+typedef void *(*GWEN_PATHIDXHANDLERPTR)(const char *entry,
                                         void *data,
                                         int idx,
                                         uint32_t flags);
@@ -203,16 +200,16 @@ typedef void* (*GWEN_PATHIDXHANDLERPTR)(const char *entry,
  * @return 0 on error, !=0 otherwise
  */
 GWENHYWFAR_API
-  void *GWEN_Path_Handle(const char *path,
-			 void *data,
-			 uint32_t flags,
-			 GWEN_PATHHANDLERPTR elementFunction);
+void *GWEN_Path_Handle(const char *path,
+                       void *data,
+                       uint32_t flags,
+                       GWEN_PATHHANDLERPTR elementFunction);
 
 GWENHYWFAR_API
-  void *GWEN_Path_HandleWithIdx(const char *path,
-				void *data,
-				uint32_t flags,
-				GWEN_PATHIDXHANDLERPTR elementFunction);
+void *GWEN_Path_HandleWithIdx(const char *path,
+                              void *data,
+                              uint32_t flags,
+                              GWEN_PATHIDXHANDLERPTR elementFunction);
 
 
 /**
@@ -222,11 +219,14 @@ GWENHYWFAR_API
  * the given buffer (without any leading slash).
  */
 GWENHYWFAR_API
-  int GWEN_Path_Convert(const char *path,
-                        GWEN_BUFFER *buffer,
-                        uint32_t flags);
+int GWEN_Path_Convert(const char *path,
+                      GWEN_BUFFER *buffer,
+                      uint32_t flags);
 
 
+GWENHYWFAR_API
+int GWEN_Path_GetPathBetween(const char *path1, const char *path2, GWEN_BUFFER *diffBuf);
+
 /*@}*/ /* defgroup */
 
 
