@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: tag16_p.h 790 2005-07-23 09:32:08Z aquamaniac $
     begin       : Sun Jun 13 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2023 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -11,8 +8,8 @@
  ***************************************************************************/
 
 
-#ifndef GWENHYWFAR_OHBCI_TAG16_P_H
-#define GWENHYWFAR_OHBCI_TAG16_P_H
+#ifndef GWENHYWFAR_PARSER_TAG16_P_H
+#define GWENHYWFAR_PARSER_TAG16_P_H
 
 
 #include "tag16.h"
@@ -23,11 +20,11 @@ struct GWEN_TAG16 {
   unsigned int tagSize;
   unsigned int tagType;
   unsigned int tagLength;
-  void *tagData;
+  const uint8_t *tagData;
   int dataOwned;
 };
 
 
 
 
-#endif /* GWENHYWFAR_OHBCI_TAG16_P_H */
+#endif /* GWENHYWFAR_PARSER_TAG16_P_H */
