@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
- -------------------
- cvs         : $Id: xsd.c 656 2004-12-22 17:02:05Z aquamaniac $
  begin       : Sat Jun 28 2003
- copyright   : (C) 2003 by Martin Preuss
+ copyright   : (C) 2021 by Martin Preuss
  email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -48,8 +45,26 @@ GWEN_INHERIT_FUNCTIONS(GWEN_XML_CONTEXT)
 
 
 
+/* ------------------------------------------------------------------------------------------------
+ * forward declarations
+ * ------------------------------------------------------------------------------------------------
+ */
 
-GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags) {
+
+static GWEN_XMLNODE *_findTagForClosingTagAndcloseAndMoveSubTags(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *currNode, const char *tagName);
+static void _moveSubTagsUpOneLevel(GWEN_XMLNODE *currNode);
+
+
+
+/* ------------------------------------------------------------------------------------------------
+ * implementations
+ * ------------------------------------------------------------------------------------------------
+ */
+
+
+
+GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags)
+{
   GWEN_XML_CONTEXT *ctx;
 
   GWEN_NEW_OBJECT(GWEN_XML_CONTEXT, ctx);
@@ -63,11 +78,14 @@ GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags) {
 
 
 
-void GWEN_XmlCtx_free(GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_free(GWEN_XML_CONTEXT *ctx)
+{
   if (ctx) {
     assert(ctx->_refCount);
     if (ctx->_refCount==1) {
       GWEN_INHERIT_FINI(GWEN_XML_CONTEXT, ctx);
+      if (ctx->encoding)
+        free(ctx->encoding);
       ctx->_refCount=0;
       GWEN_FREE_OBJECT(ctx);
     }
@@ -78,7 +96,8 @@ void GWEN_XmlCtx_free(GWEN_XML_CONTEXT *ctx) {
 
 
 
-void GWEN_XmlCtx_Attach(GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_Attach(GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   assert(ctx->_refCount);
   ctx->_refCount++;
@@ -86,42 +105,74 @@ void GWEN_XmlCtx_Attach(GWEN_XML_CONTEXT *ctx) {
 
 
 
-uint32_t GWEN_XmlCtx_GetFlags(const GWEN_XML_CONTEXT *ctx) {
+uint32_t GWEN_XmlCtx_GetFlags(const GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   return ctx->flags;
 }
 
 
 
-void GWEN_XmlCtx_SetFlags(GWEN_XML_CONTEXT *ctx, uint32_t f) {
+void GWEN_XmlCtx_SetFlags(GWEN_XML_CONTEXT *ctx, uint32_t f)
+{
   assert(ctx);
   ctx->flags=f;
 }
 
 
 
-int GWEN_XmlCtx_GetDepth(const GWEN_XML_CONTEXT *ctx) {
+const char *GWEN_XmlCtx_GetEncoding(const GWEN_XML_CONTEXT *ctx)
+{
+  assert(ctx);
+  return ctx->encoding;
+}
+
+
+
+void GWEN_XmlCtx_SetEncoding(GWEN_XML_CONTEXT *ctx, const char *encoding)
+{
+  char *s;
+
+  assert(ctx);
+  if (encoding) {
+    s=strdup(encoding);
+    assert(s);
+  }
+  else
+    s=NULL;
+  if (ctx->encoding)
+    free(ctx->encoding);
+  ctx->encoding=s;
+}
+
+
+
+int GWEN_XmlCtx_GetDepth(const GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   return ctx->depth;
 }
 
 
 
-void GWEN_XmlCtx_SetDepth(GWEN_XML_CONTEXT *ctx, int i) {
+void GWEN_XmlCtx_SetDepth(GWEN_XML_CONTEXT *ctx, int i)
+{
   assert(ctx);
   ctx->depth=i;
 }
 
 
 
-void GWEN_XmlCtx_IncDepth(GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_IncDepth(GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   ctx->depth++;
 }
 
 
 
-int GWEN_XmlCtx_DecDepth(GWEN_XML_CONTEXT *ctx) {
+int GWEN_XmlCtx_DecDepth(GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   if (ctx->depth<1)
     return -1;
@@ -131,49 +182,56 @@ int GWEN_XmlCtx_DecDepth(GWEN_XML_CONTEXT *ctx) {
 
 
 
-uint32_t GWEN_XmlCtx_GetFinishedElement(const GWEN_XML_CONTEXT *ctx) {
+uint32_t GWEN_XmlCtx_GetFinishedElement(const GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   return ctx->finishedElements;
 }
 
 
 
-void GWEN_XmlCtx_IncFinishedElement(GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_IncFinishedElement(GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   ctx->finishedElements++;
 }
 
 
 
-void GWEN_XmlCtx_ResetFinishedElement(GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_ResetFinishedElement(GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   ctx->finishedElements=0;
 }
 
 
 
-void GWEN_XmlCtx_SetCurrentNode(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *n) {
+void GWEN_XmlCtx_SetCurrentNode(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *n)
+{
   assert(ctx);
   ctx->currentNode=n;
 }
 
 
 
-GWEN_XMLNODE *GWEN_XmlCtx_GetCurrentNode(const GWEN_XML_CONTEXT *ctx) {
+GWEN_XMLNODE *GWEN_XmlCtx_GetCurrentNode(const GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   return ctx->currentNode;
 }
 
 
 
-void GWEN_XmlCtx_SetCurrentHeader(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *n) {
+void GWEN_XmlCtx_SetCurrentHeader(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *n)
+{
   assert(ctx);
   ctx->currentHeader=n;
 }
 
 
 
-GWEN_XMLNODE *GWEN_XmlCtx_GetCurrentHeader(const GWEN_XML_CONTEXT *ctx) {
+GWEN_XMLNODE *GWEN_XmlCtx_GetCurrentHeader(const GWEN_XML_CONTEXT *ctx)
+{
   assert(ctx);
   return ctx->currentHeader;
 }
@@ -181,7 +239,8 @@ GWEN_XMLNODE *GWEN_XmlCtx_GetCurrentHeader(const GWEN_XML_CONTEXT *ctx) {
 
 
 GWEN_XMLCTX_STARTTAG_FN GWEN_XmlCtx_SetStartTagFn(GWEN_XML_CONTEXT *ctx,
-    GWEN_XMLCTX_STARTTAG_FN f) {
+                                                  GWEN_XMLCTX_STARTTAG_FN f)
+{
   GWEN_XMLCTX_STARTTAG_FN of;
 
   assert(ctx);
@@ -193,7 +252,8 @@ GWEN_XMLCTX_STARTTAG_FN GWEN_XmlCtx_SetStartTagFn(GWEN_XML_CONTEXT *ctx,
 
 
 GWEN_XMLCTX_ENDTAG_FN GWEN_XmlCtx_SetEndTagFn(GWEN_XML_CONTEXT *ctx,
-    GWEN_XMLCTX_ENDTAG_FN f) {
+                                              GWEN_XMLCTX_ENDTAG_FN f)
+{
   GWEN_XMLCTX_ENDTAG_FN of;
 
   assert(ctx);
@@ -205,7 +265,8 @@ GWEN_XMLCTX_ENDTAG_FN GWEN_XmlCtx_SetEndTagFn(GWEN_XML_CONTEXT *ctx,
 
 
 GWEN_XMLCTX_ADDDATA_FN GWEN_XmlCtx_SetAddDataFn(GWEN_XML_CONTEXT *ctx,
-    GWEN_XMLCTX_ADDDATA_FN f) {
+                                                GWEN_XMLCTX_ADDDATA_FN f)
+{
   GWEN_XMLCTX_ADDDATA_FN of;
 
   assert(ctx);
@@ -217,7 +278,8 @@ GWEN_XMLCTX_ADDDATA_FN GWEN_XmlCtx_SetAddDataFn(GWEN_XML_CONTEXT *ctx,
 
 
 GWEN_XMLCTX_ADDATTR_FN GWEN_XmlCtx_SetAddAttrFn(GWEN_XML_CONTEXT *ctx,
-    GWEN_XMLCTX_ADDATTR_FN f) {
+                                                GWEN_XMLCTX_ADDATTR_FN f)
+{
   GWEN_XMLCTX_ADDATTR_FN of;
 
   assert(ctx);
@@ -228,9 +290,9 @@ GWEN_XMLCTX_ADDATTR_FN GWEN_XmlCtx_SetAddAttrFn(GWEN_XML_CONTEXT *ctx,
 
 
 
-GWEN_XMLCTX_ADDCOMMENT_FN
-GWEN_XmlCtx_SetAddCommentFn(GWEN_XML_CONTEXT *ctx,
-                            GWEN_XMLCTX_ADDCOMMENT_FN f) {
+GWEN_XMLCTX_ADDCOMMENT_FN GWEN_XmlCtx_SetAddCommentFn(GWEN_XML_CONTEXT *ctx,
+                                                      GWEN_XMLCTX_ADDCOMMENT_FN f)
+{
   GWEN_XMLCTX_ADDCOMMENT_FN of;
 
   assert(ctx);
@@ -242,7 +304,8 @@ GWEN_XmlCtx_SetAddCommentFn(GWEN_XML_CONTEXT *ctx,
 
 
 
-int GWEN_XmlCtx_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
+int GWEN_XmlCtx_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName)
+{
   assert(ctx);
 
   if (ctx->startTagFn)
@@ -255,7 +318,8 @@ int GWEN_XmlCtx_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
 
 
 
-int GWEN_XmlCtx_EndTag(GWEN_XML_CONTEXT *ctx, int closing) {
+int GWEN_XmlCtx_EndTag(GWEN_XML_CONTEXT *ctx, int closing)
+{
   assert(ctx);
 
   if (ctx->endTagFn)
@@ -268,7 +332,8 @@ int GWEN_XmlCtx_EndTag(GWEN_XML_CONTEXT *ctx, int closing) {
 
 
 
-int GWEN_XmlCtx_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
+int GWEN_XmlCtx_AddData(GWEN_XML_CONTEXT *ctx, const char *data)
+{
   assert(ctx);
 
   if (ctx->addDataFn)
@@ -281,7 +346,8 @@ int GWEN_XmlCtx_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
 
 
 
-int GWEN_XmlCtx_AddComment(GWEN_XML_CONTEXT *ctx, const char *data) {
+int GWEN_XmlCtx_AddComment(GWEN_XML_CONTEXT *ctx, const char *data)
+{
   assert(ctx);
 
   if (ctx->addCommentFn)
@@ -296,7 +362,8 @@ int GWEN_XmlCtx_AddComment(GWEN_XML_CONTEXT *ctx, const char *data) {
 
 int GWEN_XmlCtx_AddAttr(GWEN_XML_CONTEXT *ctx,
                         const char *attrName,
-                        const char *attrData) {
+                        const char *attrData)
+{
   assert(ctx);
 
   if (ctx->addAttrFn)
@@ -315,7 +382,8 @@ int GWEN_XmlCtx_AddAttr(GWEN_XML_CONTEXT *ctx,
 
 
 
-GWEN_XML_CONTEXT *GWEN_XmlCtxStore_new(GWEN_XMLNODE *n, uint32_t flags) {
+GWEN_XML_CONTEXT *GWEN_XmlCtxStore_new(GWEN_XMLNODE *n, uint32_t flags)
+{
   GWEN_XML_CONTEXT *ctx;
 
   ctx=GWEN_XmlCtx_new(flags);
@@ -334,7 +402,8 @@ GWEN_XML_CONTEXT *GWEN_XmlCtxStore_new(GWEN_XMLNODE *n, uint32_t flags) {
 
 
 
-int GWEN_XmlCtxStore_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
+int GWEN_XmlCtxStore_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName)
+{
   GWEN_XMLNODE *currNode;
   GWEN_XMLNODE *newNode;
 
@@ -372,29 +441,15 @@ int GWEN_XmlCtxStore_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
     }
 
     if (strcasecmp(s, tagName)!=0) {
+      /* current closing tag doesn't match currently open tag, check further */
       if (!(GWEN_XmlCtx_GetFlags(ctx) & GWEN_XML_FLAGS_TOLERANT_ENDTAGS)) {
-        DBG_INFO(GWEN_LOGDOMAIN,
-                 "Endtag does not match curent tag (%s != %s)", s, tagName);
+        DBG_INFO(GWEN_LOGDOMAIN, "Endtag does not match curent tag (%s != %s)", s, tagName);
         return GWEN_ERROR_BAD_DATA;
       }
       else {
-        newNode=currNode;
-
-        while( (newNode=GWEN_XMLNode_GetParent(newNode)) ) {
-          GWEN_XmlCtx_DecDepth(ctx);
-          s=GWEN_XMLNode_GetData(newNode);
-          if (strcasecmp(s, tagName)==0)
-            break;
-        }
-        if (newNode)
-          newNode=GWEN_XMLNode_GetParent(newNode);
-        if (newNode) {
-          GWEN_XmlCtx_SetCurrentNode(ctx, newNode);
-          GWEN_XmlCtx_DecDepth(ctx);
-        }
-        else {
-          DBG_INFO(GWEN_LOGDOMAIN, "No matching parent node for [%s]",
-                   tagName);
+        newNode=_findTagForClosingTagAndcloseAndMoveSubTags(ctx, currNode, tagName);
+        if (newNode==NULL) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here");
           return GWEN_ERROR_BAD_DATA;
         }
       }
@@ -425,7 +480,58 @@ int GWEN_XmlCtxStore_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
 
 
 
-int GWEN_XmlCtxStore_EndTag(GWEN_XML_CONTEXT *ctx, int closing) {
+GWEN_XMLNODE *_findTagForClosingTagAndcloseAndMoveSubTags(GWEN_XML_CONTEXT *ctx, GWEN_XMLNODE *currNode, const char *tagName)
+{
+  GWEN_XMLNODE *newNode;
+
+  newNode=currNode;
+
+  if (GWEN_XmlCtx_GetFlags(ctx) & GWEN_XML_FLAGS_SGML)
+    _moveSubTagsUpOneLevel(currNode);
+
+  while ((newNode=GWEN_XMLNode_GetParent(newNode))) {
+    const char *s;
+
+    GWEN_XmlCtx_DecDepth(ctx);
+    s=GWEN_XMLNode_GetData(newNode);
+    if (strcasecmp(s, tagName)==0)
+      break;
+    if (GWEN_XmlCtx_GetFlags(ctx) & GWEN_XML_FLAGS_SGML)
+      _moveSubTagsUpOneLevel(newNode);
+  }
+  if (newNode)
+    newNode=GWEN_XMLNode_GetParent(newNode);
+  if (newNode) {
+    GWEN_XmlCtx_SetCurrentNode(ctx, newNode);
+    GWEN_XmlCtx_DecDepth(ctx);
+    return newNode;
+  }
+  else {
+    DBG_INFO(GWEN_LOGDOMAIN, "No matching parent node for [%s]", tagName);
+    return NULL;
+  }
+}
+
+
+
+void _moveSubTagsUpOneLevel(GWEN_XMLNODE *currNode)
+{
+  GWEN_XMLNODE *childNode;
+  GWEN_XMLNODE *parentNode;
+
+  parentNode=GWEN_XMLNode_GetParent(currNode);
+  if (parentNode) {
+    while( (childNode=GWEN_XMLNode_GetFirstTag(currNode)) ) {
+      GWEN_XMLNode_UnlinkChild(currNode, childNode);
+      GWEN_XMLNode_AddChild(parentNode, childNode);
+    }
+  }
+}
+
+
+
+int GWEN_XmlCtxStore_EndTag(GWEN_XML_CONTEXT *ctx, int closing)
+{
   GWEN_XMLNODE *currNode;
 
   currNode=GWEN_XmlCtx_GetCurrentHeader(ctx);
@@ -461,7 +567,8 @@ int GWEN_XmlCtxStore_EndTag(GWEN_XML_CONTEXT *ctx, int closing) {
 
 
 
-int GWEN_XmlCtxStore_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
+int GWEN_XmlCtxStore_AddData(GWEN_XML_CONTEXT *ctx, const char *data)
+{
   GWEN_XMLNODE *currNode;
   GWEN_BUFFER *buf;
   uint32_t flags;
@@ -490,21 +597,21 @@ int GWEN_XmlCtxStore_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
     uint8_t *lastBlankPos;
     uint32_t bStart=0;
 
-    dst=(uint8_t*)GWEN_Buffer_GetStart(buf);
+    dst=(uint8_t *)GWEN_Buffer_GetStart(buf);
     src=dst;
     if (!(flags & GWEN_XML_FLAGS_KEEP_BLANKS)) {
       if (flags & GWEN_XML_FLAGS_KEEP_CNTRL) {
-        while(*src && (*src==32 || *src==9))
+        while (*src && (*src==32 || *src==9))
           src++;
       }
       else {
-        while(*src && *src<33)
+        while (*src && *src<33)
           src++;
       }
     }
 
     p=src;
-    bStart=src-((uint8_t*)GWEN_Buffer_GetStart(buf));
+    bStart=src-((uint8_t *)GWEN_Buffer_GetStart(buf));
     size=GWEN_Buffer_GetUsedBytes(buf)-bStart;
     lastWasBlank=0;
     lastBlankPos=0;
@@ -537,7 +644,7 @@ int GWEN_XmlCtxStore_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
     if (lastBlankPos!=0)
       dst=lastBlankPos;
 
-    size=dst-(uint8_t*)GWEN_Buffer_GetStart(buf);
+    size=dst-(uint8_t *)GWEN_Buffer_GetStart(buf);
     GWEN_Buffer_Crop(buf, 0, size);
   }
 
@@ -556,7 +663,8 @@ int GWEN_XmlCtxStore_AddData(GWEN_XML_CONTEXT *ctx, const char *data) {
 
 
 
-int GWEN_XmlCtxStore_AddComment(GWEN_UNUSED GWEN_XML_CONTEXT *ctx, GWEN_UNUSED const char *data) {
+int GWEN_XmlCtxStore_AddComment(GWEN_UNUSED GWEN_XML_CONTEXT *ctx, GWEN_UNUSED const char *data)
+{
   return 0;
 }
 
@@ -564,11 +672,19 @@ int GWEN_XmlCtxStore_AddComment(GWEN_UNUSED GWEN_XML_CONTEXT *ctx, GWEN_UNUSED c
 
 int GWEN_XmlCtxStore_AddAttr(GWEN_XML_CONTEXT *ctx,
                              const char *attrName,
-                             const char *attrData) {
+                             const char *attrData)
+{
   GWEN_XMLNODE *currNode;
 
   currNode=GWEN_XmlCtx_GetCurrentHeader(ctx);
   if (currNode) {
+    if ((strcmp(GWEN_XMLNode_GetData(currNode), "?xml")==0)
+        && (strcmp(attrName, "encoding")==0)) {
+      if (strcasecmp(attrData, "UTF-8")==0)
+        GWEN_XmlCtx_SetEncoding(ctx, NULL);
+      else
+        GWEN_XmlCtx_SetEncoding(ctx, attrData);
+    }
     DBG_VERBOUS(GWEN_LOGDOMAIN, "Setting attribute of header [%s]: [%s]=[%s]",
                 GWEN_XMLNode_GetData(currNode), attrName, attrData);
     GWEN_XMLNode_SetProperty(currNode, attrName, attrData);
