@@ -146,6 +146,29 @@ void Typemaker2_Builder_SetTypeManager(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPEMA
 
 
 
+void Typemaker2_Builder_AddDeclaration(TYPEMAKER2_BUILDER *tb, int access, const char *s)
+{
+  switch (access) {
+  case TypeMaker2_Access_Public:
+    Typemaker2_Builder_AddPublicDeclaration(tb, s);
+    break;
+  case TypeMaker2_Access_Library:
+    Typemaker2_Builder_AddLibraryDeclaration(tb, s);
+    break;
+  case TypeMaker2_Access_Protected:
+    Typemaker2_Builder_AddProtectedDeclaration(tb, s);
+    break;
+  case TypeMaker2_Access_Private:
+    Typemaker2_Builder_AddPrivateDeclaration(tb, s);
+    break;
+  default:
+    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid access type");
+    break;
+  }
+}
+
+
+
 void Typemaker2_Builder_AddPublicDeclaration(TYPEMAKER2_BUILDER *tb, const char *s)
 {
   assert(tb);
@@ -1587,5 +1610,35 @@ int Typemaker2_Builder_WriteFiles(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty, u
 
 
 
+int Typemaker2_Builder_PrintFileNames(TYPEMAKER2_BUILDER *tb, TYPEMAKER2_TYPE *ty)
+{
+  int rv;
+
+  rv=Typemaker2_Builder_DetermineOutFileNames(tb, ty);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    return rv;
+  }
+
+  if (GWEN_StringList_Count(tb->declarationsPublic))
+    fprintf(stdout, "%s\n", tb->fileNamePublic);
+
+  if (GWEN_StringList_Count(tb->declarationsLibrary))
+    fprintf(stdout, "%s\n", tb->fileNameLibrary);
+
+  if (GWEN_StringList_Count(tb->declarationsProtected))
+    fprintf(stdout, "%s\n", tb->fileNameProtected);
+
+  if (GWEN_StringList_Count(tb->declarationsPrivate))
+    fprintf(stdout, "%s\n", tb->fileNamePrivate);
+
+  if (GWEN_StringList_Count(tb->code))
+    fprintf(stdout, "%s\n", tb->fileNameCode);
+
+  return 0;
+}
+
+
+
 
 
