@@ -1,6 +1,6 @@
 /***************************************************************************
     begin       : Thu Jul 02 2009
-    copyright   : (C) 2009 by Martin Preuss
+    copyright   : (C) 2018 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -20,6 +20,9 @@ struct TYPEMAKER2_MEMBER {
 
   char *name;
   char *typeName;
+  char *elementName;
+
+  char *descr;
 
   int access;
 
@@ -27,6 +30,7 @@ struct TYPEMAKER2_MEMBER {
   uint32_t setFlags;
   uint32_t getFlags;
   uint32_t dupFlags;
+  uint32_t copyFlags;
 
   int maxLen;
 
@@ -42,6 +46,10 @@ struct TYPEMAKER2_MEMBER {
   TYPEMAKER2_ENUM *enumPtr;
   TYPEMAKER2_DEFINE *definePtr;
 
+  TYPEMAKER2_GROUP *groupPtr;
+
+  TYPEMAKER2_CODE_LIST *codeDefs;
+
   int refCount;
 
   int memberPosition;
